---
{"dg-publish":true,"permalink":"/bookmarks/science-and-related/folic-acid-vs-active-folate/","tags":["adhd","bestpractices","drugs","health","interesting","lifehack","science","scientific"]}
---


# [Active Folate Versus Folic Acid: The Role of 5-MTHF (Methylfolate) in Human Health](https://www.ncbi.nlm.nih.gov/pmc/articles/PMC9380836/)

> [!NOTE]
>
> Here is a concise summary of the key points:
>
> **Folate Forms and Metabolization**
>
> - Folate must be obtained from diet due to limited storage in the body.
> - Natural folates are unstable easily oxidized, and have low bioavailability.
> - Folic acid (FA) is the most commonly used form of folate supplementation, but it requires metabolic conversion to 5-MTHF to biological activity.
>
> **Drawbacks of FA**
>
> - High doses of FA can lead to rapid saturation or inhibition of dihydrofolate reductase (DHFR), resulting in accumulation of unmetabol folic acid (UMFA).
> - UMFA may compete with natural folate for transport and receptor binding, deting active folate.
> - Genetic variations that decrease DHFR activity are common, to persistent levels of UMFA.
>
> **Importance of5-MTHF**
>
> - 5-MTHF the biologically active form of folate found in blood umbilical cord blood\* It is widely available as a food ingredient and does not require metabolic conversion.
> - Supplementation with 5THF bypasses impaired folate metabolism due to MFR polymorphism.
>
> **Recommendations**
>
> - Use 5-MTHF as a supplement instead of FA for external supplementation.
> - Quatrefolic, the glucosamine salt of 5-MF, is recommended due to its high solubility and bioavailability.

- [FOLATE: SOURCES AND DEFICIENCY](-sources-and-deficiency)
  - [Folate Forms and Metabolization](-forms-and-metabolization)
    - [FA]()
    - [Natural folates]()
    - [5-MTHF]()
  - [Drawbacks of FA]()

## FOLATE: SOURCES AND DEFICIENCY

People can’t synthesize folate, and due to its water-soluble nature, the body stores it to a limited extent. Therefore, folate must be obtained from their diets.

Although naturally occurring folates are found in various foods, such as green leafy vegetables, sprouts, fruits, brewer’s yeast, and animal liver (), it’s exceedingly difficult for most people to get the daily recommended amount of folate through food alone. Furthermore, food folates are unstable, and can be oxidized by heat, light, and/or metal ions, so cooking can reduce bioavailability.

[](https://www.ncbi.nlm.nih.gov/pmc/articles/PMC9380836/figure/fig001/)

Folate intakes are typically poor in many individuals’ diets for several reasons. Natural folates: (1) are susceptible to oxidation, (2) can rapidly lose activity in foods, and (3) are largely destroyed by cooking, to 90%. Moreover, they have a low and incomplete bioavailability.

While implementing specific food-processing procedures can minimize folate degradation, the absorption of folate is much more effective with fortified foods and supplements, such as 5-MTHF/folate and folic acid. In fact, in the last decades, the main form of folate supplementation has been FA. Prescription of FA to women in the preconception period and during pregnancy is a consolidated practice.<sup><a href="https://www.ncbi.nlm.nih.gov/pmc/articles/PMC9380836/" rid="ref11">11-14</a></sup>

The recommended dietary allowances (RDAs) for folate are 400 μg/day for adults and 600 μg/day for women of childbearing age.<sup><a href="https://www.ncbi.nlm.nih.gov/pmc/articles/PMC9380836/" rid="ref15">15</a></sup> Furthermore, many countries have initiated mandatory food fortification with FA to compensate for the losses and maintain adequate dietary intakes.

Still, folate deficiency is incredibly common and may occur when: (1) dietary intake is inadequate; (2) an increased need isn’t matched by increased intake, as in physiological conditions such as pregnancy, lactation, and children’s growth; (3) absorption or excretion is altered or losses occur; or (4) metabolism or drug use interfere with the body’s ability to use folate.

Deficiency of folate may be asymptomatic or present with the symptoms of anemia, diarrhea, loss of appetite, and weight loss. Additional signs are weakness, sore tongue, headaches, heart palpitations, irritability, and behavioral disorders.<sup><a href="https://www.ncbi.nlm.nih.gov/pmc/articles/PMC9380836/" rid="ref6">6</a>,<a href="https://www.ncbi.nlm.nih.gov/pmc/articles/PMC9380836/" rid="ref16">16</a></sup>

### Folate Forms and Metabolization

The bioavailability and metabolism of the different folate forms vary due to their respective chemical structures. All forms of folates, natural or synthetic, must be converted to the circulating form 5-MTHF to exert their biological activity. The structurally related compounds included in the folate group are FA, natural folates, and 5-MTHF.

#### FA

FA is the oxidized, monoglutamate precursor form of folate that was synthesized in pure crystalline form for the first time in the 1940s. Many dietary supplements include it as do fortified foods, such as cereal-based products, pasta, enriched bread, and fruit juice. FA doesn’t occur in nature and has no biological functions. To be utilized, the human body must metabolize and reduce it to 5-MTHF using a multistep enzymatic conversion.

#### Natural folates

Natural folates occur in foods and also exist in many chemical forms of polyglutamate. Food folates are hydrolyzed to the monoglutamate form in the gut before absorption by active transport across the intestinal mucosa. Therefore, before entering the bloodstream, the monoglutamate form is reduced to tetrahydrofolate (THF) and converted into methyl forms (5-MTHF).

#### 5-MTHF

The biologically active form 5-MTHF, the predominant physiological form of folate found in blood and in umbilical cord blood, is also available in small amounts in foods. It’s widely available as a food ingredient and doesn’t require metabolization.

### Drawbacks of FA

FA is first reduced to dihydrofolate by the enzyme dihydrofolate reductase (DHFR) and then to tetrahydrofolate (THF). This is a rate-limiting step, leading to DHFR’s weak activity in humans, with considerable interindividual variations. High doses of FA can lead to a rapid saturation or inhibition of the DHFR enzyme, resulting in an accumulation of unmetabolized FA (UMFA) and the UMFA syndrome.<sup><a href="https://www.ncbi.nlm.nih.gov/pmc/articles/PMC9380836/" rid="ref13">13-17</a></sup>

Additionally, some people have genetic variations that decrease the activity of DHFR. Levels of circulating UMFA in the population are persistent in countries where the FA fortification of grains and cereals has been implemented.<sup><a href="https://www.ncbi.nlm.nih.gov/pmc/articles/PMC9380836/" rid="ref18">18</a></sup> UMFA may compete with natural folate (5-MTHF) for the folate transporter and the folate receptor, thus depleting active folate for participation in the metabolic cycles.

A 2014 published study clearly showed that 86% of FA in the hepatic portal vein is unmetabolized, while almost all the natural folate was converted correctly.<sup><a href="https://www.ncbi.nlm.nih.gov/pmc/articles/PMC9380836/" rid="ref19">19</a>,<a href="https://www.ncbi.nlm.nih.gov/pmc/articles/PMC9380836/" rid="ref20">20</a></sup> Detectable levels of UMFA occur temporarily in plasma after the consumption of >200 μg FA, with concentrations increasing in parallel to that of total FA after supplementation. UMFA has been detected in cord and infant blood, a source of concern due to potential adverse effects on health, as I will further describe.<sup><a href="https://www.ncbi.nlm.nih.gov/pmc/articles/PMC9380836/" rid="ref18">18</a>,<a href="https://www.ncbi.nlm.nih.gov/pmc/articles/PMC9380836/" rid="ref21">21</a></sup>

While it’s ideal that people obtain nutrients from food, the population can’t universally assume that it can rely on the diet for food folates. THF is a critical player in folate metabolism as a folate-acceptor molecule. THF is first converted to 5,10-methylene-THF and then later is reduced to 5-MTHF by MTHFR.<sup><a href="https://www.ncbi.nlm.nih.gov/pmc/articles/PMC9380836/" rid="ref22">22</a></sup>

Genetic polymorphism may impair the MTHFR activity and the related metabolization of food folates and folic acid in 5-MTHF. MTHFR is highly polymorphic in the general population, with multiple MTHFR gene alterations having been identified. Today, 35 rare but deleterious mutations in MTHFR, polymorphisms, and nine common variants have been reported. The two most common are C677T and A1298C. The numbers refer to their location on the gene.

A polymorphic MTHFR enzyme may function with approximately 55% to 70% efficiency as compared to a normal MTHFR enzyme. The incidence of people presenting a form of polymorphism of MTHFR is about 40% worldwide. This polymorphism is associated with an increased thermolability and reduced specific activity of MTHFR in vivo, resulting in a residual enzyme activity of 65% for heterozygous carriers and only 30% for homozygous carriers.<sup><a href="https://www.ncbi.nlm.nih.gov/pmc/articles/PMC9380836/" rid="ref23">23</a>,<a href="https://www.ncbi.nlm.nih.gov/pmc/articles/PMC9380836/" rid="ref24">24</a></sup>

The limited conversion of FA may jeopardize folate availability and increase the risk of adverse health outcomes. Cutting-edge scientific research has shed light on how much the MTHFR polymorphism is implicated in chronic disease states and how folate nutrition may contribute to replacing methylation adequately and improving overall health.

Supplementation with active folate 5-MTHF bypasses the entire folate metabolization, which is potentially impaired by MTHFR polymorphism, and 5-MTHF is directly absorbed to exert the biological activity. Therefore, using 5-MTHF as a food supplement instead of FA is strongly recommended for external supplementation.<sup><a href="https://www.ncbi.nlm.nih.gov/pmc/articles/PMC9380836/" rid="ref13">13</a></sup>

Among the available ingredients, Quatrefolic, the glucosamine salt of 5-MTHF, patented by Gnosis by Lesaffre, offers a significant advantage over previous generations of folates (). Thanks to its high solubility and bioavailability, the supplement delivers finished folate directly used by an organism without any specific form of metabolism, which makes it the ideal choice because it’s suitable for everyone regardless of MTHFR polymorphism.
