---
{"dg-publish":true,"permalink":"/bookmarks/knowledge/a-sociological-analysis-of-internet-meme-evolution-and-culture/","title":"From Proto-Memes to Brainrot: A Sociological Analysis of Internet Meme Evolution and Culture","tags":["internet","societies","ideas","history","ai"]}
---

# **From Proto-Memes to Brainrot: A Sociological Analysis of Internet Meme Evolution and Culture**

## **1\. Introduction: The Cultural Weight of Digital Ephemera**

In the contemporary digital landscape, phenomena like the viral spread of a TikTok sound or the bewildering lexicon associated with "brainrot" culture are ubiquitous. These fleeting digital artifacts, commonly known as internet memes, permeate online interactions, shape discourse, and reflect cultural currents. Yet, despite their pervasiveness, memes are often dismissed as trivial online jokes, unworthy of serious consideration. This report challenges that assumption, arguing that internet memes represent complex socio-cultural phenomena demanding rigorous sociological analysis. The very request for an expert-level sociological study underscores a growing recognition, both within academia and beyond, of the cultural and communicative significance of these digital forms. Memes are not merely fleeting entertainment; they function as potent tools for communication, mechanisms for social bonding, markers of identity, platforms for social and political commentary, and evolving artifacts of digital culture.  
This report provides a sociological analysis of the internet meme phenomenon, tracing its evolution from the earliest days of online communication to its current manifestations, including the complex cultural logic often termed "brainrot." It begins by establishing a clear, academically grounded definition of the internet meme, contrasting foundational concepts with contemporary understandings. Subsequently, it charts the historical trajectory of memes through distinct technological eras: the pre-social media "proto-meme" period of Usenet and forums; the rise of image-centric formats during the Facebook era; the aesthetic and temporal shifts driven by visually oriented platforms like Instagram and Vine; and the algorithmically charged, participatory environment of TikTok and Twitch. A dedicated section analyzes the contemporary "brainrot" phenomenon, examining its characteristics and potential sociological significance. Throughout this historical analysis, relevant sociological and media theories are integrated to illuminate the functions and transformations of meme culture. Finally, drawing upon this synthesis of empirical evidence and theoretical perspectives, the report proposes a novel sociological framework—a Socio-Algorithmic Model—designed to provide a structured approach for understanding the creation, diffusion, interpretation, and cultural logic of internet memes, including brainrot. This comprehensive analysis aims to demonstrate the value of studying memes as crucial indicators and active agents within digital society.

## **2\. Defining the Digital Meme: From Cultural Genes to Participatory Units**

To analyze the phenomenon of internet memes, a clear conceptual foundation is necessary. The term "meme" itself predates the internet, requiring an understanding of its origins and subsequent adaptation to the digital sphere.

### **2.1 Dawkins' Original "Meme" Concept**

The term "meme" was coined by evolutionary biologist Richard Dawkins in his influential 1976 book, _The Selfish Gene_. Dawkins proposed the meme as a cultural analogue to the biological gene – a "unit of cultural transmission" or a "unit of imitation". Examples included melodies, catchphrases, fashion trends, and architectural techniques. He argued that these cultural units spread from person to person through copying or imitation, replicating themselves much like genes replicate biologically.  
Dawkins applied principles of Darwinian evolution to culture, suggesting that memes undergo processes of variation, competition, selection, and retention. Memes, like genes, were described as "selfish" replicators, meaning their primary "goal" is their own propagation, sometimes irrespective of benefit or harm to their human hosts. This perspective was further elaborated by quoting psychologist Nicholas Humphrey, who suggested memes act like viruses parasitizing the brain to ensure their own spread.  
However, Dawkins himself later acknowledged a distinction between his original concept and the phenomenon of _internet_ memes. While his initial formulation emphasized replication through imitation, often implying high fidelity, he characterized internet memes as being deliberately altered by human creativity, rather than mutating through random change. This distinction highlights a key tension: the original biological analogy struggled to fully account for the intentional modification and remixing inherent in much of digital meme culture. Furthermore, the concept faced criticism for its ambiguity and the difficulty in defining or quantifying a discrete "unit" of culture compared to the concrete basis of the gene in DNA.

### **2.2 Shifman's Internet Meme Definition**

Addressing the specificities of digital culture, communication scholar Limor Shifman offered a more precise and widely adopted definition of the _internet_ meme. Shifman defines an internet meme as: **"(a) a group of digital items sharing common characteristics of content, form, and/or stance, which (b) were created with awareness of each other, and (c) were circulated, imitated, and/or transformed via the Internet by many users"**.  
This definition marks several crucial departures from Dawkins' original concept. Firstly, it shifts the focus from a single "unit" to a "group of digital items". This acknowledges that online, users often encounter numerous variations of a meme simultaneously, experiencing it as a collective phenomenon rather than an isolated idea. Secondly, and critically, Shifman's definition explicitly incorporates _transformation_ alongside imitation. This highlights the active role of users in not just replicating but also altering, remixing, and adapting memes – a central characteristic of participatory digital culture. This emphasis on user agency and transformation directly addresses the limitations of the purely replicative biological analogy and the critique that the term "meme" had been "hijacked" by internet culture.  
The internet, therefore, did not merely provide a new conduit for pre-existing memetic processes; its interactive and networked nature fundamentally reshaped the phenomenon itself. The ease of digital copying, manipulation, and mass sharing allowed memes to evolve from passively replicated cultural units (Dawkins' initial focus ) into dynamic, user-driven, collective expressions (Shifman's focus ). Shifman's definition reflects this co-evolution of the concept and the technology.  
To facilitate analysis, Shifman proposed three key dimensions of internet memes :

1. **Content:** Refers to the ideas, ideologies, and themes expressed within the meme. What is being said or represented?
2. **Form:** Encompasses the physical incarnation of the meme – its visual and/or auditory characteristics, including format, genre patterns, and aesthetic style. How is the message presented?
3. **Stance:** Relates to the information the meme conveys about its own communication. This includes participation structures (who is creating/sharing/remixing), the tone and style (e.g., humorous, ironic, serious), and the communicative functions it performs (e.g., social commentary, group bonding, self-expression). How are participants positioning themselves and the message?

These dimensions provide a structured way to analyze the multifaceted nature of internet memes, moving beyond simple descriptions of content.

### **2.3 Distinguishing Memes from Virals**

Shifman's framework also helps clarify the often-confused distinction between "memes" and "virals". While both involve rapid spread online, Shifman argues that **viral content comprises a _single_ cultural unit** (like a specific video, photo, or joke) that propagates in many identical or near-identical copies. In contrast, **an internet meme is always a _collection_ of texts or items**. A single viral video is not the meme itself, but potentially _one manifestation_ of a meme if it inspires imitation, parody, and transformation by other users, creating a group of related items.  
The popular video "Gangnam Style," for instance, initially went viral as a single unit. It became a _meme_ when countless users created their own parodies and variations ("Mitt Romney Style," "NASA Johnson Style," etc.), forming a group of related digital items created with awareness of each other. This distinction underscores the participatory and transformative element central to Shifman's definition of internet memes, differentiating them from content that merely spreads widely without significant user modification. It also counters the simplistic "meme-as-virus" analogy, which often portrays audiences as passive recipients rather than active participants in cultural production and circulation.

### **2.4 Key Characteristics of Internet Memes**

Synthesizing insights from various scholars and observations of online culture, several key characteristics define internet memes:

- **Creative Reproduction:** Memes are adapted and transformed through imitation (mimicry) or technological manipulation (remix).
- **Intertextuality:** They blend different cultural texts, references, or contexts to create new meanings.
- **Viral Dissemination (Fecundity):** They possess the capacity to spread rapidly through online networks. Factors like humor, intertextuality, and juxtaposition enhance spreadability.
- **Evolution and Longevity (with caveats):** Memes change over time, yet longevity is crucial for circulation and evolution. However, internet memes often represent fleeting trends compared to the long-term endurance of traditional cultural memes.
- **Replicability (vs. Fidelity):** While traditional memes emphasize accurate copying (fidelity), internet memes prioritize replicability, allowing for modification while maintaining a core message or format.
- **Humor and Juxtaposition:** Humor is a common, though not universal, element, often arising from unexpected combinations or incongruity.
- **In-Group Signaling & Community Building:** Memes often function as inside jokes, conveying specific knowledge and fostering collective identity within online communities.

The gap often noted between the vernacular use of "meme" to describe any popular, often short-lived online trend and more rigorous academic definitions highlights a persistent challenge in studying dynamic popular culture. Shifman's framework, by defining memes as groups of related, transformed items analyzed through content, form, and stance , attempts to bridge this divide. It acknowledges the user-centric experience of encountering meme variations (content, form) while providing analytical tools (stance) to understand their deeper communicative and social functions, moving beyond simply labeling something as "viral" or a "fad."

## **3\. The Proto-Meme Era: Seeds of Digital Folklore (Pre-2005)**

Before the rise of centralized social media platforms, the nascent internet fostered unique forms of digital communication and community, laying the groundwork for what would become modern meme culture. This "proto-meme" era, roughly spanning from the advent of networked computing into the early 2000s, saw the emergence of distinct formats, characteristics, and influential online spaces.

### **3.1 Early Digital Environments**

The technological landscape of this period consisted primarily of decentralized or semi-centralized systems like Usenet newsgroups, email chains, Bulletin Board Systems (BBS), early web forums (such as Something Awful and 4chan, which emerged towards the end of this period), Multi-User Dungeons (MUDs), and Internet Relay Chat (IRC). These platforms facilitated communication within often niche communities. It was within this context, specifically regarding Usenet discussions in 1993, that Mike Godwin first coined the term "Internet meme," observing the replication of certain ideas or comparisons within these groups.

### **3.2 Formats and Characteristics**

Memes during this era were heavily influenced by the technological constraints of the time. Common formats included:

- **Text-based humor:** Jokes, stories, and arguments propagated through plain text.
- **ASCII art:** Using text characters to create images, a workaround for limited graphical capabilities.
- **Emoticons:** Simple text-based representations of faces, like Scott Fahlman's :-) from 1982\.
- **Early GIFs:** Simple, often looping animations like the Dancing Baby.
- **Email Forwards:** Chain letters, urban legends, jokes, and early forms of spam spread through email lists.
- **Signatures:** Personalized text appended to emails or forum posts, sometimes containing quotes or ASCII art.
- **Simple Image Manipulations:** Basic photoshops or edits, often shared on forums.

Key characteristics defined these early memes:

- **Slower Spread:** Compared to later eras, diffusion was less instantaneous, relying on deliberate forwarding or posting within specific groups.
- **Longer Lifespan:** Memes tended to persist for longer periods within communities before fading.
- **Reliance on In-Group Knowledge:** Many early memes functioned as inside jokes, requiring familiarity with specific forum culture, technical knowledge, or shared history to be understood.
- **Early Remix Culture:** Despite simplicity, elements of parody and remix were present, such as altering text captions on images or adapting email formats.

### **3.3 Key Examples**

Several iconic examples emerged from this period:

- **Dancing Baby (1996):** A 3D animation that went viral via email and early websites, even appearing on mainstream television (Ally McBeal), demonstrating early meme characteristics like rapid spread and mutation.
- **Hampster Dance (1998):** A GeoCities page featuring rows of dancing hamster GIFs set to sped-up music, spread via email and newsgroups, eventually spawning merchandise and music hits.
- **"All Your Base Are Belong To Us" (2001):** Originating from a poorly translated line in the video game _Zero Wing_, this phrase was remixed into countless images and videos, becoming a hallmark of early internet humor and demonstrating creative reproduction and intertextuality.
- **Kilroy Was Here:** While originating offline during WWII, this simple graffiti drawing is often cited as an analogue to early meme behavior – a replicable symbol spreading through imitation.
- **Spam Memes:** Early forms of internet spam, like MAKE.MONEY.FAST chain letters or the Monty Python-inspired flooding of chatrooms with the word "spam," became memetic in their own right, reflecting early internet culture and norms.

### **3.4 Sociological Lens: Digital Folklore and Incubators**

This era can be understood sociologically as the genesis of **digital folklore**. Just as traditional folklore transmits stories, jokes, and customs orally, these early digital platforms facilitated the transmission of cultural artifacts (jokes, images, phrases) within networked communities. **Symbolic Interactionism** provides a lens to understand how shared meanings emerged within these niche groups through the repeated use and interpretation of specific symbols, whether emoticons, ASCII art, or recurring phrases like "All Your Base". Meaning was constructed collectively within the context of these early online interactions.  
Furthermore, early **Network Theory** concepts help explain diffusion patterns. Memes spread not randomly, but through specific network channels – Usenet hierarchies, email lists, connections within BBSs or forums. The structure of these early networks influenced how and where memes propagated.  
Platforms like 4chan and Something Awful played a crucial role as cultural incubators. Their often anonymous or pseudonymous nature fostered distinct subcultures characterized by specific humor styles (often dark, ironic, or offensive), insider slang, and visual aesthetics. These platforms were influential in establishing early meme formats (like image macros originating on Something Awful ) and norms, including trolling and "flaming," which would ripple outwards as internet culture evolved. While technologically simpler, this era established foundational logics of meme culture – remix, intertextuality, and community identity through shared symbols – that persist today. The social functions of memes were evident even before the sophisticated tools and mass audiences of later platforms.

## **4\. The Platformization Begins: Facebook and the Image Macroocene (Mid-2000s \- Early 2010s)**

The mid-2000s marked a significant shift in the internet landscape with the rise of centralized social media platforms. Sites like MySpace, YouTube, early Twitter, and particularly Facebook, transitioned online interaction from niche forums and email lists to large-scale, profile-based networks. This "platformization" profoundly impacted meme culture, ushering in an era dominated by specific visual formats and new modes of participation and circulation.

### **4.1 Dominance of Templated Formats: Image Macros and Rage Comics**

This period witnessed the explosion and widespread popularization of highly templated meme formats, most notably Image Macros and Rage Comics.

- **Image Macros:** These became the quintessential meme format of the era. Defined by text (often in bold, white Impact font with a black outline ) overlaid on a background image, they relied on recognizable characters or scenarios. Key subgenres included:
    - **LOLCats:** Images of cats paired with humorous, often intentionally misspelled captions ("lolspeak"), originating on sites like 4chan but popularized by blogs like "I Can Has Cheezburger?" (launched 2007).
    - **Advice Animals:** Featuring stock characters (often animals, but also humans) against a colored background (frequently a pinwheel), with setup text at the top and punchline text at the bottom. Examples include Courage Wolf, Socially Awkward Penguin, Scumbag Steve, and Bad Luck Brian. The term "Advice Animals" itself is a misnomer, as the text often involved confessions, observations, or imperatives rather than actual advice.
- **Rage Comics:** Characterized by crudely drawn faces (often made in MS Paint) expressing exaggerated emotions (e.g., "FUUUUU-", Trollface, Forever Alone) arranged in simple multi-panel narratives depicting relatable or humorous situations. These comics were highly flexible and expressive, covering a wide range of emotions and scenarios.

The success of these formats stemmed largely from their **template-based nature**. Pre-defined characters, visual layouts, and emotional expressions provided a framework that users could easily adapt by adding their own text. The proliferation of online **meme generators** further lowered the barrier to entry, allowing users without graphic design skills to participate in meme creation. This ease of creation fueled a massive surge in user-generated content and participation.  
This era represents a significant moment of **democratization** in meme culture, making creation accessible to a much broader audience than the more technically demanding or culturally niche formats of the proto-meme era. However, this democratization also led to a notable **standardization** of meme aesthetics. The visual language of memes became heavily dominated by these specific, often formulaic, templates and styles (like the Impact font), particularly on platforms like Facebook and Reddit where they flourished.

### **4.2 Propagation Mechanisms: Facebook's Networked Audience**

Facebook became a primary engine for meme circulation during this time. Unlike the often-anonymous or pseudonymous communities of the past, Facebook's profile-based structure meant memes were shared within visible social networks of friends, family, and acquaintances. Sharing occurred through personal profiles, dedicated meme pages, and groups, leveraging the platform's built-in sharing functionalities. This aligns with Henry Jenkins' concept of **spreadability**, where content's potential for audience sharing is key to its circulation. The networked structure allowed memes to potentially reach vast audiences far beyond the niche communities where they might have originated.

### **4.3 Algorithmic Influence: The Shadow of EdgeRank**

The visibility and spread of memes on Facebook were not solely determined by user sharing but were also mediated by the platform's algorithm. Prior to roughly 2013-2014, Facebook's News Feed was primarily governed by an algorithm known internally (and later publicly) as **EdgeRank**. EdgeRank calculated the relevance of posts based on three main factors :

1. **Affinity:** The strength of the relationship between the user and the content creator (e.g., frequency of interaction).
2. **Weight:** The type of interaction or content (e.g., comments weighted more than likes, photos/videos potentially weighted more than text links).
3. **Time Decay:** The recency of the post (older posts become less visible).

While primitive by today's standards, EdgeRank likely played a role in shaping the meme landscape of its time. By prioritizing content that generated high engagement (likes, shares, comments) and potentially favoring visual formats like photos (the basis of image macros), the algorithm may have inadvertently amplified the dominance of these easily digestible and highly shareable meme types. Content that performed well under EdgeRank's criteria would gain more visibility, encouraging the creation and sharing of similar content, thus reinforcing the popularity of formats like Advice Animals and LOLCats.  
A study conducted by researchers at the University of Michigan and Facebook, analyzing text-based status update memes shared between 2009 and 2011 (before the "Share" button, requiring manual copy-pasting), provides evidence of platform mechanics influencing meme evolution. The study found that these text memes mutated and spread in ways strikingly similar to gene evolution, fitting models like the Yule process. Variations occurred, selection favored certain versions (often shorter ones or those incorporating popular phrases borrowed from other memes), and the network structure influenced propagation. This demonstrates how even basic platform mechanics (like copy-pasting) and network effects, potentially amplified by algorithmic sorting like EdgeRank, could shape memetic evolution.  
Facebook later publicly acknowledged moving beyond the simple EdgeRank model, incorporating machine learning and thousands of factors. Notably, around 2013-2014, Facebook announced algorithm changes explicitly aimed at _reducing_ the visibility of low-quality content and "meme photos" in favor of "high-quality content" (like news articles) or posts from friends and family, suggesting an awareness and perhaps a course-correction regarding the type of content its earlier algorithm had potentially favored.

### **4.4 Social Functions: Identity, Commentary, Community**

During this era, memes solidified their role as significant tools for social interaction and cultural expression within mainstream online spaces:

- **Identity Expression:** Sharing specific memes became a way for users to signal their personality, humor, values, affiliations, and relatable experiences to their social network. The choice of which Advice Animal or Rage Comic resonated was a form of self-presentation within the Facebook environment.
- **Social Commentary:** Memes served as accessible vehicles for commenting on and critiquing current events, politics, pop culture, and everyday social norms. Their often humorous or satirical nature made potentially sensitive topics more approachable.
- **Community Building:** Shared understanding and appreciation of specific memes fostered a sense of belonging and collective identity within online groups and friend networks. Laughing at the same joke or relating to the same depicted struggle reinforced social bonds.

### **4.5 Theoretical Integration**

Several sociological theories illuminate this era:

- **Symbolic Interactionism:** Explains how templated formats like Advice Animals became shared symbols, with users collectively negotiating their meanings and using them to interact and construct identity online. The meaning wasn't inherent in the image but emerged through its repeated use with specific types of text within the community.
- **Social Constructionism:** Highlights how the shared experience of creating, circulating, and interpreting memes helped construct a shared reality and set of norms within Facebook communities and broader internet culture. Memes became part of the "social construction" of online life.
- **Cultural Studies:** Views memes as cultural artifacts that both reflect and shape popular culture, ideologies, and social dynamics of the time. The types of humor, characters, and situations depicted in dominant memes reveal insights into the cultural preoccupations of the era.
- **Participatory Culture (Jenkins):** This framework is highly relevant, as the ease of creating templated memes lowered barriers to expression, encouraged creation and sharing, and fostered a sense where user contributions mattered within the memetic landscape. Rage comics, in particular, allowed for storytelling and emotional expression accessible even without artistic skill.

This era represents a crucial stage where memes transitioned from niche subcultural artifacts to mainstream social media phenomena, driven by platform affordances, user participation, and the early influence of algorithmic curation.

## **5\. The Visual & Ephemeral Turn: Instagram and Vine Aesthetics (Early-Mid 2010s)**

Following the initial wave of platformization dominated by Facebook and templated image macros, the early to mid-2010s saw the rise of platforms prioritizing different forms of media: the visually curated aesthetic of Instagram and the hyper-short, looping videos of Vine. These platforms fostered distinct meme cultures, characterized by new formats, aesthetics, modes of participation, and an acceleration of meme lifecycles.

### **5.1 Instagram's Influence: Aesthetics, Curation, and Relatability**

Launched initially as a photo-sharing app, Instagram's emphasis on visual presentation significantly shaped the memes that thrived on its platform.

- **Aesthetics and Visual Culture:** Instagram's grid layout, filters, and overall focus on visually appealing content encouraged memes that were more aesthetically considered than the often crude or standardized look of earlier image macros. While not all Instagram memes were polished, the platform's environment fostered a greater awareness of visual style. This period saw the rise of dedicated **meme accounts**, where users curated feeds of humorous or relatable content, often developing a specific aesthetic or thematic focus. This act of **curation** itself became a form of creation and identity expression. Some accounts, part of what has been termed "Weird Instagram," used the platform's influencer-oriented features to develop authorial personas, blending personal expression with memetic content and playing with identity.
- **Formats:** While image macros persisted, Instagram's format encouraged other visual meme types. **Screenshots** of text messages, tweets (often from Tumblr initially ), or other online interactions became common, framed as relatable or humorous scenarios. **Relatable quote graphics**, often featuring simple text over an aesthetic background, also gained popularity. The platform's visual nature made it a potent space for political memes and commentary, sometimes functioning as "networked flak" critical of mainstream media or power structures.

### **5.2 Vine's Impact: Constraints, Creativity, and Stars**

Vine, operational from 2013 to 2017, introduced a radical constraint: videos could be a maximum of six seconds long and looped continuously. This unique format had a profound impact on meme culture.

- **Creativity Through Constraint:** The six-second limit forced creators to be exceptionally concise and inventive. Humor often relied on perfect timing, quick cuts, unexpected twists, repetition inherent in the loop, or physical comedy. Stop-motion animation and clever video editing techniques also flourished. Vine became a breeding ground for a specific style of short-form comedic storytelling.
- **Vine Stars and Early Influencer Culture:** The platform launched the careers of numerous individuals who became known as "Vine Stars" (e.g., Shawn Mendes, Logan Paul, Lele Pons, King Bach, Thomas Sanders). These creators amassed huge followings by mastering the six-second format and creating highly shareable, often memetic content. This marked a significant moment where meme creation and dissemination became visibly intertwined with **influencer culture** and the potential for monetization (often through brand deals off-platform, as Vine itself had limited monetization options ). The departure of top creators due to these limitations contributed to Vine's eventual decline.
- **Trends and Challenges:** Vine culture was heavily driven by trends, challenges (like the Ice Bucket Challenge ), and recurring audio snippets or catchphrases that users would replicate and remix. This participatory element was key to its vibrancy.

### **5.3 Accelerated Meme Cycles and Platform Affordances**

Both Instagram and Vine contributed to an acceleration of meme lifecycles compared to the previous era. Vine's extremely short format encouraged rapid consumption and creation, leading to trends burning brightly but potentially fading quickly. Instagram's algorithmic feed (evolving beyond EdgeRank during this period) and visual immediacy also facilitated faster discovery and sharing.  
The concept of **platform affordances** – the features, constraints, and cultural norms of a platform that enable or encourage certain types of user behavior – is crucial here. Instagram's affordances (filters, grid, emphasis on photography) shaped its meme culture towards aesthetics and relatability. Vine's affordances (6-second limit, looping, touch-to-record camera, sound integration, revining) directly fostered its unique brand of rapid-fire, often absurdist, looping comedy.  
The distinct technical constraints and features of each platform acted as environmental pressures, cultivating specific "species" of memes and associated creative practices. This strongly echoes Marshall McLuhan's famous dictum, **"The medium is the message"**. The very structure of Vine _was_ its message, shaping the content into short, looping, often humorous bursts. Similarly, Instagram's structure emphasized visual curation and shareable aesthetics. The platforms were not neutral containers but active participants in shaping the cultural forms (memes) produced and circulated within them.

### **5.4 Theoretical Integration**

This era invites analysis through several theoretical lenses:

- **Visual Culture:** Essential for understanding Instagram's impact, focusing on how images create meaning, circulate, and shape social understanding in a visually saturated environment.
- **Media Ecology:** McLuhan's ideas about how media technologies function as environments that shape perception and culture are particularly relevant to understanding the distinct impacts of Vine's constraints versus Instagram's visual focus.
- **Platform Studies:** Analyzing the specific affordances and architectures of Instagram and Vine helps explain _why_ certain meme formats and cultures emerged on each platform.
- **Postmodernism:** Theories of pastiche (imitating styles), irony, and the blurring of high/low culture can be applied to the remix culture prevalent on both platforms, especially Vine's absurdist humor.
- **Sociology of Humor:** Theories explaining humor through incongruity, timing, and repetition are useful for analyzing Vine's comedic forms.

This period represents a diversification and acceleration of meme culture, driven by the unique affordances of new, highly popular platforms. It also marks the point where meme creation became visibly linked to the burgeoning influencer economy, setting the stage for the even more complex dynamics of the TikTok era.

## **6\. The Algorithmic Crucible: TikTok's Sound, Remix, and Trend Ecology (Late 2010s \- Present)**

The late 2010s witnessed the meteoric rise of TikTok, a platform that has profoundly reshaped the landscape of internet memes and digital culture. Building on the short-form video legacy of Vine but integrating powerful algorithmic curation and sophisticated remixing tools, TikTok fostered a unique ecosystem where memes are generated, circulated, and experienced in novel ways.

### **6.1 TikTok's Platform Logic: Algorithm, Sound, and Remix**

Understanding TikTok's impact requires grasping its core features and underlying logic:

- **Short-Form Video:** While lengths have varied, the platform is fundamentally built around short, easily consumable videos.
- **The "For You" Page (FYP):** Unlike feed algorithms primarily based on social connections (like early Facebook), TikTok's FYP is driven by a powerful recommendation algorithm that curates a personalized, seemingly endless stream of content based on inferred user interests, engagement patterns (watch time, likes, shares, comments), video information (hashtags, sounds), and device settings. This prioritizes content relevance over creator popularity, allowing videos from unknown accounts to achieve massive virality.
- **Emphasis on Sound:** Audio – including licensed music snippets, original sounds, and voiceovers – is a central organizing principle and creative element on TikTok. Sounds themselves become memetic, driving trends and imitation. Clicking on a sound often leads to a page showcasing countless other videos using the same audio.
- **Integrated Remix Tools:** Features like **Duets** (split-screen reactions/collaborations), **Stitches** (incorporating clips from other videos), filters, effects, and readily available sound libraries make remixing and participating in trends incredibly easy and integral to the platform's experience.

### **6.2 Algorithmic Culture and Algorithmic Memetics**

TikTok exemplifies the concept of **algorithmic culture**, where algorithms are not just passive distributors of content but actively shape cultural production, circulation, taste, and user behavior. The FYP algorithm acts as a powerful curator and gatekeeper, determining which memes and trends gain visibility and traction. Creators often tailor their content to appeal to perceived algorithmic preferences, aiming for virality by participating in trending challenges, using popular sounds, or adopting specific formats.  
This deep integration of the algorithm into the cultural fabric of the platform suggests a move towards **algorithmic memetics**. Here, the algorithm itself becomes a key agent in the memetic process, influencing selection (by promoting engaging or trend-aligned content), variation (by providing tools like Duet/Stitch that encourage specific types of remix), and replication (by amplifying content across FYPs). The platform's logic rewards participation in trends it surfaces, creating feedback loops that accelerate meme evolution and potentially homogenize content around algorithmically favored formats. This intertwines meme dynamics with platform architecture and algorithmic governance more explicitly than in previous eras.

### **6.3 Participatory Culture at Scale and Remix**

TikTok dramatically scales up the principles of **participatory culture** described by Henry Jenkins. The platform's design actively encourages users to become creators, not just consumers. Features like easily reusable sounds, filters, Duets, and Stitches lower the barriers to artistic expression and civic engagement significantly, allowing users to quickly remix, respond to, and build upon existing content. This fosters a culture of **"technological mimesis"** – imitation and replication driven by the platform's tools and logic. Users form "imitation publics" based on shared participation in trends or use of specific sounds/effects, rather than solely on pre-existing social ties.  
However, while participation is widespread, the algorithmic emphasis on _trending_ content raises questions about the autonomy and direction of this participation. Are users freely creating, or are they primarily channeling their creativity into formats and themes rewarded by the algorithm? The intense focus on virality, driven by the algorithm's potential to grant massive visibility , may incentivize conformity to trends over radical originality.

### **6.4 Globalization and Localization**

TikTok's algorithmic reach enables the rapid **globalization** of memes and trends. A sound, dance, or challenge originating in one country can quickly spread worldwide, creating shared cultural moments across diverse populations. However, the platform also facilitates **localization**. Global trends are often adapted with local references, languages, or cultural nuances. Furthermore, the algorithm can surface locally relevant content, allowing distinct regional or national meme cultures to flourish alongside global ones. Studies comparing TikTok use across countries show variations linked to national cultural values, demonstrating this interplay between global platform logic and local cultural contexts. For example, the Indonesian "Don't Play Play Bosku" meme exemplifies local adaptation of platform features , while analysis of Southeast Asian TikTok reveals localization of Western extremist memes.

### **6.5 Evolution of Meme Formats**

TikTok has shifted the dominant form of memes decisively towards **short-form video** incorporating **sound, performance, and participation**. While image-based memes still exist, the platform's core memetic currency involves replicating video formats, participating in challenges, lip-syncing to sounds, or using specific filters and effects in performative ways. This represents a significant evolution from the text-and-image focus of the Facebook era and the purely visual or looping-gag focus of the Instagram/Vine era.  
In conclusion, the TikTok era is defined by the profound influence of its recommendation algorithm and remix-oriented features. It fosters an unprecedented scale of participation but channels it through algorithmically promoted trends, sounds, and formats. This creates a dynamic, rapidly evolving, and increasingly globalized yet locally adaptable meme culture, fundamentally altering how memes are created, discovered, and experienced.

## **7\. Contemporary Currents: Understanding "Brainrot" Culture (Present)**

Emerging from the hyper-accelerated, algorithmically-driven environments of platforms like TikTok and Twitch, a distinct cultural phenomenon and internet slang term has gained prominence: "brainrot". Analyzing brainrot offers crucial insights into the current state of internet culture, particularly among younger generations (Gen Z and Gen Alpha).

### **7.1 Defining "Brainrot"**

Brainrot, named Oxford Word of the Year 2024 , is defined as **"the supposed deterioration of a person's mental or intellectual state, especially viewed as the result of overconsumption of material (now particularly online content) considered to be trivial or unchallenging. Also: something characterized as likely to lead to such deterioration"**. Merriam-Webster defines it as "Mindless digital content; the fixation on it and harmful mental effects of it". Dictionary.com adds it can describe an "intense and often obsessive preoccupation with a particular topic".  
While the term itself has historical roots (used by Thoreau in 1854 to critique intellectual decline ), its modern usage surged in the 2020s, particularly within online communities associated with Gen Z and Gen Alpha. It initially gained traction in fandom circles to describe obsessions but evolved to encompass both the low-quality content itself and its perceived negative effects.

### **7.2 Characteristics of Brainrot Culture**

Brainrot culture is characterized by several key features:

- **Association with Low-Value, Absurd, and Repetitive Content:** It is primarily linked to online content perceived as nonsensical, meaningless, trivial, overly stimulating, repetitive, or lacking artistic/intellectual substance. This includes certain types of memes, viral challenges, short video loops, and specific online slang.
- **Niche References and Slang:** Brainrot culture often involves highly specific, rapidly evolving slang, in-jokes, and references that are unintelligible to outsiders. Mastery of this lexicon functions as a marker of in-group status.
- **Rapid Obsolescence and High Velocity:** The trends, slang, and memes associated with brainrot have extremely short lifecycles, emerging and fading at an accelerated pace. This reflects the high speed and ephemerality of content circulation on platforms like TikTok.
- **"Terminally Online" Association:** The term is strongly linked to the concept of being "chronically online" or "terminally online" – spending excessive amounts of time immersed in digital environments, potentially leading to a disconnect from offline reality and norms.
- **Self-Aware and Ironic Usage:** Crucially, "brainrot" is often used ironically or self-deprecatingly by individuals who actively participate in and consume the culture it describes. This suggests a level of meta-awareness about their own media consumption habits.
- **Links to Information Overload and Attention Economy:** The phenomenon is frequently discussed in relation to concerns about the cognitive impacts of digital media, such as shortened attention spans, mental fog, cognitive overload, and addiction, often attributed to platform designs that prioritize constant stimulation and engagement (e.g., infinite scroll, short-form video algorithms).

### **7.3 Platforms and Examples**

Brainrot culture is most strongly associated with **TikTok** and the live-streaming platform **Twitch**. The rapid-fire, algorithmically curated nature of TikTok's FYP and the interactive, often repetitive, and emote-driven culture of Twitch chat provide fertile ground for brainrot phenomena.  
Specific examples frequently cited include :

- **Skibidi Toilet:** An animated YouTube series featuring singing toilet creatures, known for its absurdity and repetitive nature. The term "skibidi" itself has become brainrot slang, often meaning nonsensical or used as filler.
- **Gyatt:** An exclamation, often used in response to seeing an attractive person (particularly their posterior).
- **Rizz / Rizzler:** Slang for charisma or flirting ability; a "rizzler" is someone possessing such ability.
- **Sigma / Alpha / Beta:** Terms borrowed (often ironically or incorrectly) from sociobiology or fringe online ideologies to denote perceived social hierarchies, particularly among men.
- **Ohio:** Used humorously to refer to anything strange, bizarre, or cursed, stemming from "Only in Ohio" memes.
- **Fanum Tax:** Refers to playfully stealing a friend's food, popularized by Twitch streamer Fanum.
- **Mewing / Looksmaxxing / Mogging:** Terms related to online trends focused on optimizing physical appearance, particularly facial structure.
- **Gooning / Edging:** Terms related to specific sexual practices, often used humorously or absurdly in memes.
- **Twitch Culture:** Specific emotes (like DansGame , Kappa , LUL ), repetitive chat spam, streamer catchphrases, and parasocial interactions contribute to a distinct Twitch-based brainrot.

### **7.4 Sociological Interpretations: Brainrot as Cultural Logic**

From a sociological perspective, "brainrot" is more than just a collection of silly memes or slang. It represents a distinct **cultural logic** that has emerged from, and responds to, the conditions of contemporary digital life. This logic is characterized by:

- **Absurdity and Nihilism:** A response to the overwhelming and often meaningless deluge of online information, embracing nonsense as a form of humor or commentary.
- **Extreme Ephemerality:** Reflecting the accelerated pace of digital culture, where trends and meanings shift constantly.
- **Intertextual Overload:** Memes constantly reference other memes, slang, and niche online events, creating dense layers of meaning accessible only to the initiated.
- **Performative Participation:** Engaging with brainrot often involves performing knowledge of the slang and references, reinforcing in-group identity.
- **Coping/Resistance:** It can be interpreted as a way for users, particularly younger generations, to cope with the pressures of being constantly online, the anxieties of the modern world, or the perceived meaninglessness of algorithmically curated feeds, using humor and absurdity as tools.

This cultural logic is deeply intertwined with the **attention economy** and the experience of **information overload**. Platforms designed to maximize engagement through constant, novel stimuli may inadvertently foster the conditions for brainrot, leading to concerns about cognitive effects like reduced attention spans and mental fatigue.  
A key paradox lies in the term's usage. While "brainrot" carries negative connotations of mental decline and low-value content , it is simultaneously embraced and deployed _within_ the very online communities (Gen Z/Alpha on TikTok/Twitch) most associated with it, often playfully and self-referentially. This suggests the term operates on multiple levels: as a critique of digital excess, a marker of digital nativity and in-group belonging, an ironic acceptance of online conditions, and perhaps even a form of playful resistance or adaptation to the overwhelming nature of contemporary digital culture.

## **8\. Theoretical Synthesis: Lenses for Understanding Meme Culture**

The evolution of internet memes, from early digital folklore to the complex dynamics of brainrot, cannot be fully grasped through a single theoretical lens. Understanding this multifaceted phenomenon requires integrating insights from various sociological and media theories, recognizing how their relevance shifts across different technological and cultural eras.

### **8.1 Integrating Theoretical Perspectives**

Several key theoretical frameworks offer valuable perspectives on meme culture:

- **Symbolic Interactionism:** This micro-level theory emphasizes how individuals create and interpret meaning through shared symbols and interactions. Applied to memes, it illuminates how specific images, phrases, or formats (like Advice Animals or Trollface) become imbued with collective meaning within online communities. It also sheds light on how sharing and engaging with memes contributes to the construction of online identities and the presentation of self. The meaning of a meme is not fixed but negotiated and reinforced through ongoing interaction.
- **Social Constructionism:** This perspective posits that reality and social phenomena are collectively constructed through social processes. Memes are powerful tools in this process, helping to shape shared understandings of events, social issues, and group norms within online spaces. The collective creation and iteration of memes literally construct a shared cultural reality for participants.
- **Network Theory:** This framework focuses on the structure of connections and the flow of information within networks. It is essential for modeling and understanding meme diffusion, virality, and spread patterns. Concepts like hubs, weak/strong ties, and community structures help explain why some memes spread further or faster than others.
- **Cultural Studies:** This broad field examines culture as a site of power, ideology, and meaning-making. It allows for the analysis of memes as cultural artifacts that reflect, reinforce, or challenge dominant ideologies, social norms, and power structures. It also highlights the role of memes in subcultural expression and resistance. Memes become forms of digital cultural capital, signifying belonging and status within specific groups.
- **Theories of Play and Humor:** These theories help explain the appeal and function of memes as playful communication. Concepts like incongruity-resolution (central to humor in Advice Animals ), satire, and absurdity are crucial for understanding the affective and social bonding dimensions of meme sharing.
- **Postmodernism/Metamodernism:** Postmodern concepts like irony, pastiche (remixing existing styles/texts), skepticism towards grand narratives, and the blurring of high/low culture resonate strongly with meme culture's aesthetics and practices. Metamodernism's focus on the oscillation between irony and sincerity may capture the complex tone of some contemporary meme phenomena, including brainrot's self-aware critique.
- **Media Ecology (McLuhan):** This perspective emphasizes how the characteristics of communication media (the "environment") shape human perception, social organization, and cultural content. It helps explain how the shift from text-based Usenet to image-centric Facebook to video/algorithmic TikTok fundamentally altered the _form_ and _nature_ of memes ("the medium is the message").
- **Participatory Culture (Jenkins):** This theory highlights the shift towards a media landscape where audiences are also active producers and distributors of content, characterized by low barriers to entry, support for creation/sharing, informal mentorship, and a sense that contributions matter. Meme culture is a prime example of participatory culture in action.
- **Algorithmic Culture:** This emerging perspective analyzes how algorithms increasingly mediate cultural production, circulation, and consumption, shaping tastes, visibility, and creative practices \[

#### **Bibliografia**

1\. 'Brain rot' named Oxford Word of the Year 2024, https://corp.oup.com/news/brain-rot-named-oxford-word-of-the-year-2024/ 2\. Brainrot: Understanding Meme Culture and Digital Obsession Among Gen Alpha, https://www.thinkhousehq.com/the-youth-lab/uhhh-brainrot 3\. The meme culture that is making us go grey \- The Daily Iowan, https://dailyiowan.com/2025/03/04/the-meme-culture-that-is-making-us-go-grey/ 4\. Laugh Out Loud: How Early Internet Memes Redefined Humor in Pop Culture \- Ask.com, https://www.ask.com/culture/laugh-loud-early-internet-memes-redefined-humor-pop-culture 5\. (PDF) Memes as the Phenomenon of Modern Digital Culture \- ResearchGate, https://www.researchgate.net/publication/343824151\_Memes\_as\_the\_Phenomenon\_of\_Modern\_Digital\_Culture 6\. Memes: The language of the internet that overcomes cultural barriers \- Journalift, https://journalift.org/memes-the-language-of-the-internet-that-overcomes-cultural-barriers/ 7\. Meme Culture: A Study of Humor and Satire in Digital Media \- ResearchGate, https://www.researchgate.net/publication/382370919\_Meme\_Culture\_A\_Study\_of\_Humor\_and\_Satire\_in\_Digital\_Media 8\. Memes and Metamodernism: An Analysis of a Medium \- Western CEDAR, https://cedar.wwu.edu/cgi/viewcontent.cgi?article=1110\&context=wwu\_honors 9\. Social media changes life cycle of memes \- The Post \- Athens, https://www.thepostathens.com/article/2025/02/life-cycle-meme-social-media 10\. TikTok, and the Evolution of Meme Culture \- Mack Grenfell, https://mackgrenfell.com/blog/tiktok-and-the-evolution-of-meme-culture 11\. Future Center \- How Creative Content Mitigates Brain Rot on Social Media, https://futureuae.com/en-US/Mainpage/Item/9913/breaking-absurdity-how-creative-content-mitigates-brain-rot-on-social-media 12\. Memes in Digital Culture ( MIT Press Essential Knowledge Series): Limor Shifman, https://www.amazon.com/Memes-Digital-Culture-Essential-Knowledge/dp/1469004194 13\. Book Review: Memes in Digital Culture by Limor Shifman \- LSE Research Online, https://eprints.lse.ac.uk/56253/1/Book\_Review\_Memes\_in\_Digital\_Culture\_by\_Limor\_Shifman\_LSE\_Review\_of\_Books.pdf 14\. Polyvocal Digital Discourse: A Review of Shifman's Memes in Digital Culture | enculturation, https://enculturation.net/memes-in-digital-culture 15\. Memes: In Digital Culture (MIT Press Essential Knowledge) \- Amazon.com, https://www.amazon.com/Memes-Digital-Culture-Essential-Knowledge/dp/1469004186 16\. Full article: Memes in digital culture, https://www.tandfonline.com/doi/full/10.1080/1369118X.2014.979217 17\. A Review of “Memes in Digital Culture” \- ProQuest, https://www.proquest.com/scholarly-journals/review-memes-digital-culture/docview/2555208603/se-2 18\. Review by LauraAnne Carroll-Adler, University of Southern California \- Technoculture, https://tcjournal.org/vol5/carroll-adler/ 19\. Meme Culture: How User-Generated Content Sells Stuff | UO SOJC, https://journalism.uoregon.edu/news/keegan-pond-meme-culture 20\. Are memes a useful concept for academic study? : r/philosophy \- Reddit, https://www.reddit.com/r/philosophy/comments/ot1ce/are\_memes\_a\_useful\_concept\_for\_academic\_study/ 21\. Is there any serious scholarly work on the Internet and "meme" culture? : r/Anthropology, https://www.reddit.com/r/Anthropology/comments/1iqrwe/is\_there\_any\_serious\_scholarly\_work\_on\_the/ 22\. Full article: Methodological and epistemological challenges in meme research and meme studies \- Taylor & Francis Online, https://www.tandfonline.com/doi/full/10.1080/24701475.2024.2359846 23\. Memes in a Digital World: Reconciling with a Conceptual Troublemaker \- Oxford Academic, https://academic.oup.com/jcmc/article/18/3/362/4067545 24\. What Do You Meme? An Analysis of How College Students at Central Washington University Use Memes, https://digitalcommons.cwu.edu/cgi/viewcontent.cgi?article=1039\&context=undergrad\_hontheses 25\. UAFS Professor Focuses on Meme Research, https://uafs.edu/news/\_drupal/4816.php 26\. internet memes as form of cultural discourse: a rhetorical analysis on facebook \- OSF, https://osf.io/sx6t7/download 27\. (PDF) Internet Meme: A Virtual Visual Artefact of Digital Visual Culture, https://www.researchgate.net/publication/354658701\_Internet\_Meme\_A\_Virtual\_Visual\_Artefact\_of\_Digital\_Visual\_Culture 28\. Memes and Constructions of TikTok Culture in \#DontPlayPlayBosku \- Redfame Publishing, https://redfame.com/journal/index.php/smc/article/download/6842/6553 29\. Memes: An Overview \- Easy Sociology, https://easysociology.com/sociology-of-media/memes-an-overview/ 30\. Memes and Social Engineering \- Easy Sociology, https://easysociology.com/sociology-of-media/memes-and-social-engineering/ 31\. Book review: Memes in digital culture by Limor Shifman \- LSE Research Online, http://eprints.lse.ac.uk/56253/ 32\. Internet meme \- Wikipedia, https://en.wikipedia.org/wiki/Internet\_meme 33\. Memes in a Digital World: Reconciling with a Conceptual Troublemaker \- ResearchGate, https://www.researchgate.net/publication/263564026\_Memes\_in\_a\_Digital\_World\_Reconciling\_with\_a\_Conceptual\_Troublemaker 34\. I Read A Book:Limor Shifman's Memes in Digital Culture \- The Learned Fangirl, https://thelearnedfangirl.com/memes-in-digital-culture/ 35\. Review of Memes in Digital Culture, by Limor Shifman (MIT Press) | Improspectives, https://improspectives.com/2014/01/06/review-of-memes-in-digital-culture-by-limor-shifman-mit-press/ 36\. The Birth of a Meme \- What is it Anyway? | Old Dominion University, https://www.odu.edu/news/2018/2/birth\_of\_meme 37\. Spirit of Play | Where do memes come from? \- Spielwarenmesse, https://www.spielwarenmesse.de/en/mag/marketing/where-do-memes-come-from/ 38\. The Role of Memes in Shaping Political Discourse on Social Media \- Redfame Publishing, https://redfame.com/journal/index.php/smc/article/download/7482/6790 39\. Internet Memes: Culture & History | StudySmarter, https://www.studysmarter.co.uk/explanations/media-studies/digital-and-social-media/internet-memes/ 40\. Memes Explained \- Why are they funny? | Supermeme.ai, https://supermeme.ai/memes 41\. The role of memes in the construction of Facebook personae | Request PDF \- ResearchGate, https://www.researchgate.net/publication/271623834\_The\_role\_of\_memes\_in\_the\_construction\_of\_Facebook\_personae 42\. Memetics across Generations: Demographics and Meme Usage \- ResearchGate, https://www.researchgate.net/publication/386043598\_Memetics\_across\_Generations\_Demographics\_and\_Meme\_Usage 43\. THE MEME AS A FORM OF COMMUNICATION ON THE INTERNET \- ResearchGate, https://www.researchgate.net/publication/364714120\_THE\_MEME\_AS\_A\_FORM\_OF\_COMMUNICATION\_ON\_THE\_INTERNET 44\. Internet Memes: Leaflet Propaganda of the Digital Age \- Frontiers, https://www.frontiersin.org/journals/communication/articles/10.3389/fcomm.2020.547065/full 45\. View of Linguistic and Semiotic Analysis of Memes with English and Arabic Humor Captions \- Journal of Intercultural Communication, https://www.immi.se/index.php/intercultural/article/view/AlIssawi-2024-4/1007 46\. What Do You Meme: How Memes Enhance Digital Communication and Culture \- Pictory, https://pictory.ai/blog/memes-digital-culture 47\. What Do They Meme? Exploring the Role of Memes as Cultural Symbols of Online Communities | Request PDF \- ResearchGate, https://www.researchgate.net/publication/378875807\_What\_Do\_They\_Meme\_Exploring\_the\_Role\_of\_Memes\_as\_Cultural\_Symbols\_of\_Online\_Communities 48\. Contextualizing Internet Memes Across Social Media Platforms \- arXiv, https://arxiv.org/html/2311.11157v2 49\. The role of Internet memes in creating a sense of belonging and community in an online setting, https://www.bellisario.psu.edu/medialab/research-article/the-role-of-internet-memes-in-creating-a-sense-of-belonging-and-community-i 50\. The Efficacy of Using Internet Memes to Communicate Political Messages By: Amanda Vodicka \- Englewood Public Library, https://englewood.marmot.org/Archive/fortlewis:18987/DownloadPDF 51\. The Shellshocked Meme: A Journey Through History, Humor, And Humanity \- The Age Flip, https://staging.mozingolake.com/azermantis-017/the-shellshocked-meme-a-journey-through-history-humor-and-humanity.html 52\. Memes and Aesthetics: The Evolution of Digital Art in Popular Culture \- Olga Guarch, https://www.guarcholga.es/memes-and-aesthetics-the-evolution-of-digital-art-in-popular-culture/ 53\. Meme culture and evolution | Language and Popular Culture Class Notes \- Fiveable, https://library.fiveable.me/language-popular-culture/unit-9/meme-culture-evolution/study-guide/EZay3TgJhJWX44ih 54\. Insights from cross-cultural memes: An empirical study on instagram ..., https://www.researchgate.net/publication/383592995\_Insights\_from\_cross-cultural\_memes\_An\_empirical\_study\_on\_instagram\_and\_Douban 55\. Instagram and the Memed Self \- InVisible Culture, https://www.invisibleculturejournal.com/pub/keye-instagram 56\. spir.aoir.org, https://spir.aoir.org/ojs/index.php/spir/article/download/11958/10329/75860 57\. Vine Memes Quotes: The Ultimate Guide To The Best Viral Moments \- Urban Future, https://voip.egfgunclub.org/instamoments/vine-memes-quotes-the-ultimate-guide-to-the-best-viral-moments.html 58\. The Meme Generation: Social Media Platforms Address Content Curation, https://www.sociallyawareblog.com/topics/the-meme-generation-social-media-platforms-address-content-curation 59\. The Rise of Short-Form Video Content: Engaging Gen Z on TikTok \- Choco Up, https://choco-up.com/blog/short-form-video-gen-z-tiktok 60\. Inside TikTok 2024: A Report on Trends, Music, and Global Impact \- House of Marketers, https://www.houseofmarketers.com/tiktok-key-trends-of-2024/ 61\. Psychological Perspectives on Participatory Culture: Core Motives ..., https://jspp.psychopen.eu/index.php/jspp/article/view/6377/8763 62\. Full article: Youth activism and (de)personalized remix on TikTok \- Taylor & Francis Online, https://www.tandfonline.com/doi/full/10.1080/14742837.2024.2415672?af=R 63\. Memes as Global Communication \- RhetComp \- WordPress.com, https://rhetcompatstonybrook.wordpress.com/2016/11/12/memes-as-global-communication/ 64\. The Evolution of Memes: From Dawkins to Digital Culture | Learning People, https://www.learningpeople.com/uk/resources/blog/what-is-the-history-behind-the-cultural-phenomenon-of-memes/ 65\. How Memes and Media Are Crafting the Way We See War \- Fielding Graduate University, https://www.fielding.edu/how-memes-and-media-are-crafting-the-way-we-see-war/ 66\. Cross-cultural meme adaptation | Language and Popular Culture Class Notes \- Fiveable, https://fiveable.me/language-popular-culture/unit-9/cross-cultural-meme-adaptation/study-guide/JzwRQRM7Xb3fUBCe 67\. Complete Brainrot Wiki guide to Understand Brainrot | PDFToBrainrot \- PDF to Brainrot, https://pdftobrainrot.org/brainrot-wiki 68\. Brainrot: Boom or Doom? \- The Corydon, https://millikancorydon.com/6165/opinion/brainrot-boom-or-doom/ 69\. The Rise of “Brain Rot”: A Sociolinguistic Perspective on Gen Z and Gen Alpha's Digital Vernacular \- BILD-LIDA, https://bild-lida.ca/educationalsociolinguistics/uncategorized/the-rise-of-brain-rot-a-sociolinguistic-perspective-on-gen-z-and-gen-alphas-digital-vernacular/ 70\. The Rise of Cross-Language Internet Memes: A Social Semiotic Analysis | Signs and Society | Cambridge Core, https://www.cambridge.org/core/journals/signs-and-society/article/rise-of-crosslanguage-internet-memes-a-social-semiotic-analysis/31F51B74D8B240C73689358176615E55 71\. Sociological Definition of the Concept of «Internet-Meme»: Away From «Meme», https://sociostudios.vnu.edu.ua/index.php/socio/article/view/391 72\. Analysis of the use of memes as an exponent of collective coping during COVID-19 in Puerto Rico \- PMC \- PubMed Central, https://pmc.ncbi.nlm.nih.gov/articles/PMC8280555/ 73\. Memes: The Interaction Between Imagery and Subculture: An Analysis of Situation, Race, and Gender on the Pi Kappa Delta \- UKnowledge, https://uknowledge.uky.edu/cgi/viewcontent.cgi?article=1003\&context=oswald 74\. Cognitive, Emotional, and Social Factors of Internet Meme Appreciation \- OSF, https://osf.io/xdn9m/download/?format=pdf 75\. Memes \- Contexts, https://contexts.org/articles/memes/ 76\. DHQ: Digital Humanities Quarterly: A Review of Memes in Digital ..., https://www.digitalhumanities.org/dhq/vol/10/2/000243/000243.html 77\. Meme \- Wikipedia, https://en.wikipedia.org/wiki/Meme 78\. The Selfish Gene \- Wikipedia, https://en.wikipedia.org/wiki/The\_Selfish\_Gene 79\. The history of memes \- Interrobang, https://www.theinterrobang.ca/article?aID=14598 80\. Memetics \- Wikipedia, https://en.wikipedia.org/wiki/Memetics 81\. McGrady & Hamm 1 A Meme is Worth a Thousand Words, https://spiral.lynn.edu/cgi/viewcontent.cgi?article=1750\&context=facpubs 82\. Meme \- Oxford Reference, https://www.oxfordreference.com/display/10.1093/acref/9780195120905.001.0001/acref-9780195120905-e-187 83\. What Happens If You Say “Meme” \- LSE, https://www.lse.ac.uk/Economic-History/Assets/Documents/Research/FACTS/reports/memes.pdf 84\. Memes and other fictions — TOK RESOURCE.ORG \- 2025, https://www.tokresource.org/memes 85\. How Richard Dawkins Coined the Word Meme: The Legendary Atheist's Surprising Religious Inspiration \- The Marginalian, https://www.themarginalian.org/2013/10/02/richard-dawkins-meme-appetite-for-wonder/ 86\. Meme | Definition, Meaning, History, & Facts \- Britannica, https://www.britannica.com/topic/meme 87\. The lifecycle of memes | Request PDF \- ResearchGate, https://www.researchgate.net/publication/271508690\_The\_lifecycle\_of\_memes 88\. Defining and characterizing the concept of Internet Meme \- SciELO Colombia, http://www.scielo.org.co/scielo.php?script=sci\_arttext\&pid=S2011-30802013000200007 89\. “I Has Seen Image Macros\!” Advice Animal Memes as Visual-Verbal ..., https://ijoc.org/index.php/ijoc/article/viewFile/4101/1556 90\. Memetics as Informational Difference: Offering an Information-Centric Conception of Memes \- SURFACE at Syracuse University, https://surface.syr.edu/cgi/viewcontent.cgi?article=1015\&context=ischoolstudents 91\. www.digitalhumanities.org, https://www.digitalhumanities.org/dhq/vol/10/2/000243/000243.html\#:\~:text=Using%20this%20approach%2C%20Shifman%20offers,Internet%20by%20many%20users%E2%80%9D%20%5BShifman 92\. A Meme is a Terrible Thing to Waste: An Interview with Limor Shifman (Part One), http://henryjenkins.org/blog/2014/02/a-meme-is-a-terrible-thing-to-waste-an-interview-with-limor-shifman-part-one.html 93\. Exploring Commonalities of Shared Viral Memes on Facebook and Implications, https://journals.indexcopernicus.com/publication/4399723 94\. arXiv:2102.03952v1 \[cs.SI\] 8 Feb 2021, https://arxiv.org/pdf/2102.03952 95\. Pastiche | Literary Theory and Criticism Class Notes \- Fiveable, https://library.fiveable.me/literary-theory-criticism/unit-12/pastiche/study-guide/fW9uhVOpMpwXUAWQ 96\. Meme ranking to maximize posts virality in microblogging platforms \- Carlos Castillo (ChaTo), https://chato.cl/papers/meme\_ranking\_maximize\_posts\_virality\_microblogging\_ienco\_bonchi\_castillo.pdf 97\. Community Aware Models of Meme Spreading in Micro-blog Social Networks \- PMC, https://pmc.ncbi.nlm.nih.gov/articles/PMC7302255/ 98\. Scalable Detection of Viral Memes from Diffusion Patterns \- ResearchGate, https://www.researchgate.net/publication/325913122\_Scalable\_Detection\_of\_Viral\_Memes\_from\_Diffusion\_Patterns 99\. Scalable Detection of Viral Memes from Diffusion Patterns \- Yong-Yeol Ahn, https://yongyeol.com/papers/hui2018scalable.pdf 100\. Entropy and complexity unveil the landscape of memes evolution \- PMC \- PubMed Central, https://pmc.ncbi.nlm.nih.gov/articles/PMC8501102/ 101\. Blast from the Past: 20 Early Internet Memes That Defined a Simpler Time \- Cheezburger, https://cheezburger.com/19786501/blast-from-the-past-20-early-internet-memes-that-defined-a-simpler-time 102\. (PDF) “I has seen Image Macros\!” Advice Animals memes as visual-verbal jokes., https://www.researchgate.net/publication/293464876\_I\_has\_seen\_Image\_Macros\_Advice\_Animals\_memes\_as\_visual-verbal\_jokes 103\. BRAIN ROT Slang Meaning | Merriam-Webster, https://www.merriam-webster.com/slang/brain-rot 104\. brainrot Meaning & Origin | Slang by Dictionary.com, https://www.dictionary.com/e/slang/brainrot/ 105\. What Is Brainrot? \- YouTube, https://m.youtube.com/watch?v=WAJ6H3nMGPk 106\. How brainrot humour infected the internet with surreal gibberish \- Dazed, https://www.dazeddigital.com/life-culture/article/62947/1/how-brainrot-humour-infected-the-internet-with-surreal-gibberish-tiktok-skibidi 107\. 40 Brainrot Slang Words and Phrases Explained \- Game Quitters, https://gamequitters.com/brainrot-slang/ 108\. A “Brain Rot” Breakdown \- The Voyager, https://voyager-online.org/13082/creative/a-brain-rot-breakdown/ 109\. From reels to reality, brainrot skibidi swings current trends \- The Purple Tide, https://chantillynews.org/15240/opinions/from-reels-to-reality-brainrot-skibidi-swings-current-trends/ 110\. Know your meme: internet pop culture is the new language of activism \- News at Curtin, https://www.curtin.edu.au/news/know-your-meme-internet-pop-culture-is-the-new-language-of-activism/ 111\. Pepe the Frog: A Case Study of the Internet Meme and its Potential Subversive Power to Challenge Cultural Hegemonies \- Scholars' Bank, https://scholarsbank.uoregon.edu/items/b3c2120f-d947-43cd-b186-246e8ae026b8 112\. \[META\] I created an analysis of postmodernism in memes : r/surrealmemes \- Reddit, https://www.reddit.com/r/surrealmemes/comments/61szun/meta\_i\_created\_an\_analysis\_of\_postmodernism\_in/ 113\. An introduction to metamodernism: the cultural philosophy of the digital age \- Ness Labs, https://nesslabs.com/metamodernism 114\. When did "meme" suddenly start meaning "any text on a photo of an animal"? \- Reddit, https://www.reddit.com/r/OutOfTheLoop/comments/3c3fk2/when\_did\_meme\_suddenly\_start\_meaning\_any\_text\_on/ 115\. The Complete Guide to Spam Memes: History, Impact, and Greatest Hits \- Mystrika, https://blog.mystrika.com/spam-memes/ 116\. A Dank History of Memes | FYI \- Vocal Media, https://vocal.media/fyi/a-dank-history-of-memes 117\. The History Of Dank Memes | 01 \- Vocal Media, https://vocal.media/01/the-history-of-dank-memes 118\. Online Communities and Social Networking: Its History (& What's Next) \- Insticator, https://www.insticator.com/online-communities-and-social-networking-its-history-whats-next/ 119\. ELI5: What is Usenet? Who used it back in the 80's? How can you access Usenet today? : r/explainlikeimfive \- Reddit, https://www.reddit.com/r/explainlikeimfive/comments/p78k03/eli5\_what\_is\_usenet\_who\_used\_it\_back\_in\_the\_80s/ 120\. What was early internet like? : r/90sdesign \- Reddit, https://www.reddit.com/r/90sdesign/comments/17ey04r/what\_was\_early\_internet\_like/ 121\. Early internet meme videos : r/RedditForGrownups, https://www.reddit.com/r/RedditForGrownups/comments/adpnh2/early\_internet\_meme\_videos/ 122\. What was the first Internet meme? : r/AskReddit, https://www.reddit.com/r/AskReddit/comments/ld8jz/what\_was\_the\_first\_internet\_meme/ 123\. Something Awful \- Wikipedia, https://en.wikipedia.org/wiki/Something\_Awful 124\. Something Awful \- WikiFur, the furry encyclopedia, https://en.wikifur.com/wiki/Something\_Awful 125\. early internet culture : r/CuratedTumblr \- Reddit, https://www.reddit.com/r/CuratedTumblr/comments/1clew8e/early\_internet\_culture/ 126\. An Oral History of Something Awful \- Hacker News, https://news.ycombinator.com/item?id=14121584 127\. \[Internet Culture\] SomethingAwful, Danganronpa, & Tumblr: The Birth of a Fandom & a Paywall : r/HobbyDrama \- Reddit, https://www.reddit.com/r/HobbyDrama/comments/lo9lhp/internet\_culture\_somethingawful\_danganronpa/ 128\. Image macro \- Wikipedia, https://en.wikipedia.org/wiki/Image\_macro 129\. Remembering Advice Animals, one of the internet's first viral memes \- Mashable, https://mashable.com/article/what-happened-to-advice-animals 130\. A funny thing happened on the way from the forum: the life and death of internet memes., https://conservancy.umn.edu/items/5bd2059f-89a8-42ba-bfd3-526dccc5600f 131\. (PDF) Visual memes in social media: tracking real-world news in YouTube videos \- ResearchGate, https://www.researchgate.net/publication/221572966\_Visual\_memes\_in\_social\_media\_tracking\_real-world\_news\_in\_YouTube\_videos 132\. www.fer.unizg.hr, https://www.fer.unizg.hr/\_download/repository/8\_Extending%20the%20Internet%20meme%20Conceptualizing%20technological%20mimesis%20and%20imitation%20publics%20on%20the%20TikTok%20platform.pdf 133\. Internet slang and memes | Language and Popular Culture Class Notes \- Fiveable, https://library.fiveable.me/language-popular-culture/unit-6/internet-slang-memes/study-guide/nwJnWFW6CgHp9DyX 134\. From LOLcats to Prehistoric Penises: The History of Memes \- The Bubble, https://www.thebubble.org.uk/culture/history/from-lolcats-to-prehistoric-penises-the-history-of-memes/ 135\. Too Long; Couldn't Tweet: All your memes are belong to us (with GIFS\!) \- Random Nerds, https://randomnerds.com/too-long-couldnt-tweet-all-your-memes-are-belong-to-us-with-gifs/ 136\. A Guide to Memes & Meme Culture \- More By Us, https://moreby.us/resources/blog/a-guide-to-memes-meme-culture/ 137\. List of Internet phenomena \- Wikipedia, https://en.wikipedia.org/wiki/List\_of\_Internet\_phenomena 138\. Fuck You And Die: An Oral History of Something Awful \- VICE, https://www.vice.com/en/article/fuck-you-and-die-an-oral-history-of-something-awful/ 139\. 'Something Awful' is an awfully good book | Rough and Rede II, https://georgerede.wordpress.com/2020/11/23/something-awful-is-an-awfully-good-book/ 140\. Internet Memes of the '90s: Thanks for the meme-ories \- CMA, https://cmagency.co.uk/internet-memes-of-the-90s-thanks-for-the-meme-ories/ 141\. Hampster Dance \- Wikipedia, https://en.wikipedia.org/wiki/Hampster\_Dance 142\. The Symbolic Interactionist View of Media in Sociology, https://easysociology.com/sociological-perspectives/symbolic-interactionism/the-symbolic-interactionist-view-of-media-in-sociology/ 143\. What is Symbolic Interactionism Theory? | Background & Uses \- ATLAS.ti, https://atlasti.com/research-hub/symbolic-interactionism-theory 144\. CMV: In retrospect, rage comics were one of the best Internet memes in recent history. \- Reddit, https://www.reddit.com/r/changemyview/comments/4f7e5f/cmv\_in\_retrospect\_rage\_comics\_were\_one\_of\_the/ 145\. ELI5: Why/how did Rage Comics die out so fast? : r/explainlikeimfive \- Reddit, https://www.reddit.com/r/explainlikeimfive/comments/4df1xn/eli5\_whyhow\_did\_rage\_comics\_die\_out\_so\_fast/ 146\. Memetic memory as vital conduits of troublemakers in digital culture \- SURFACE at Syracuse University, https://surface.syr.edu/cgi/viewcontent.cgi?article=1021\&context=ischoolstudents 147\. Inside the Facebook Algorithm in 2025: All the Updates You Need to Know \- Buffer, https://buffer.com/library/facebook-news-feed-algorithm/ 148\. Facebook News Feed Changed Everything, https://slate.com/technology/2013/09/facebook-news-feed-turns-7-why-its-the-most-influential-feature-on-the-internet.html 149\. The Future Influence of TikTok on Evolving Social Media Trends: A Comprehensive Analysis, https://www.researchgate.net/publication/383861287\_The\_Future\_Influence\_of\_TikTok\_on\_Evolving\_Social\_Media\_Trends\_A\_Comprehensive\_Analysis 150\. The Influence of Social Media in Shaping Global Cultural Trends \- Multipost Digital, https://www.multipostdigital.com/blog/9qdw4lmonpopdryopsv6bmg375zgd7 151\. TikTok: How Meme Culture Has Transformed the App \- SnoQap, https://www.snoqap.com/posts/2020/1/13/tiktok-how-meme-culture-has-transformed-the-app-ywz7k 152\. (PDF) BRAIN ROT: OVERCONSUMPTION OF ONLINE CONTENT (AN ESSAY ON THE PUBLICNESS SOCIAL MEDIA) \- ResearchGate, https://www.researchgate.net/publication/387558941\_BRAIN\_ROT\_OVERCONSUMPTION\_OF\_ONLINE\_CONTENT\_AN\_ESSAY\_ON\_THE\_PUBLICNESS\_SOCIAL\_MEDIA 153\. 6 Best Meme Fonts You Need to Create the Funniest Meme \- FlexClip, https://www.flexclip.com/learn/meme-font.html 154\. Meme Generator: Free Meme Maker for Images, Videos & Text \- Kapwing, https://www.kapwing.com/meme-maker 155\. “I Has Seen Image Macros\!” Advice Animals Memes as Visual-Verbal Jokes | Dynel, https://ijoc.org/index.php/ijoc/article/view/4101 156\. Does else anyone remember rage comics? Kind of weird how these used to be everywhere and completely vanished off the internet around 2014\. : r/GenZ \- Reddit, https://www.reddit.com/r/GenZ/comments/1cnhg6d/does\_else\_anyone\_remember\_rage\_comics\_kind\_of/ 157\. rage comic will forever be in my heart : r/dankmemes \- Reddit, https://www.reddit.com/r/dankmemes/comments/hv52fw/rage\_comic\_will\_forever\_be\_in\_my\_heart/ 158\. I present a rage comic I made in like 2012 that I thought was the peak of humor at the time \- Reddit, https://www.reddit.com/r/ComedyCemetery/comments/98v78u/i\_present\_a\_rage\_comic\_i\_made\_in\_like\_2012\_that\_i/ 159\. I was a top-secret, paid meme expert for Facebook \- The Black and White, https://theblackandwhite.net/67701/alsoinprint/i-was-a-top-secret-paid-meme-expert-for-facebook/ 160\. 8: The Circulation, Delivery, and Spreadability of Memes – Digital Publishing, https://wordpress.susqu.edu/engl390/2018/03/22/8-the-circulation-delivery-and-spreadability-of-memes/ 161\. Henry Jenkins \- Wikipedia, https://en.wikipedia.org/wiki/Henry\_Jenkins 162\. EdgeRank: Give your Facebook page the edge \- Wordtracker, https://www.wordtracker.com/academy/social/facebook/edgerank-facebook-ranking 163\. Facebook's News Feed Algorithm: A Guide To Recent Changes | MarTech, https://martech.org/21-news-feed-updates-that-have-changed-how-pages-use-facebook/ 164\. The Evolution of the Facebook Algorithm: A Decade of Transformation \- Markinuity, https://markinuity.com/uncategorized/the-evolution-of-the-facebook-algorithm/ 165\. Nobody Can Understand How Facebook Algorithm Works\! \- KHALIL TRABELSI, http://www.khaliltrabelsi.com/nobody-can-understand-how-facebook-algorithm-works/ 166\. EdgeRank Is Dead: Facebook's News Feed Algorithm Now Has Close To 100K Weight Factors | MarTech, https://martech.org/edgerank-is-dead-facebooks-news-feed-algorithm-now-has-close-to-100k-weight-factors/ 167\. EdgeRank: Facebook's Algorithm Explained \- Fusion 360, https://fusion360agency.com/edgerank-facebooks-algorithm-explained/ 168\. The World of Edgerank: Rhetorical Justifications of Facebook's News Feed Algorithm, http://computationalculture.net/the-world-of-edgerank-rhetorical-justifications-of-facebooks-news-feed-algorithm/ 169\. Facebook memes can evolve like genes | University of Michigan News, https://news.umich.edu/facebook-memes-can-evolve-like-genes/ 170\. The biology of a Facebook meme \- The Horizons Tracker, https://adigaskell.org/2014/01/20/the-biology-of-a-facebook-meme/ 171\. How a meme spreads on Facebook: The amazing image that shows how posts become popular \- Daily Mail, https://www.dailymail.co.uk/sciencetech/article-2541482/How-meme-spreads-Facebook-The-amazing-image-shows-posts-popular.html 172\. Facebook News Feed Algorithm History | 2025 Update \- Wallaroo Media, https://wallaroomedia.com/facebook-newsfeed-algorithm-history/ 173\. It's Not You, It's Facebook's News Feed Algorithm \- Precision Strategies, https://www.precisionstrategies.com/its-not-you-its-facebooks-news-feed-algorithm/ 174\. Facebook algorithm: brand post reach dipping, memes get the axe? \- The American Genius, https://theamericangenius.com/facebook-algorithm-changing-brand-post-reach-dipping-memes-get-axe/ 175\. Facebook 'split memes' are driving everyone crazy \- Mashable, https://mashable.com/article/facebook-split-memes 176\. DISSERTATION THE AFFECT AND EFFECT OF INTERNET MEMES: ASSESSING PERCEPTIONS AND INFLUENCE OF ONLINE USER-GENERATED POLITICAL DIS, https://mountainscholar.org/bitstreams/a480a659-f8c7-4f43-a399-c2a97f4497d4/download 177\. Twitch user perceptions, attitudes and behaviours in relation to food and beverage marketing on Twitch compared with YouTube, https://pmc.ncbi.nlm.nih.gov/articles/PMC8141682/ 178\. INTRODUCTION \- What is Participatory Culture? \- Aaron Delwiche and Jennifer Jacobs Henderson, https://williamwolff.org/wp-content/uploads/2013/09/delwiche-2013.pdf 179\. INSTAGRAM AND YOUTUBE,VISUAL CULTURE AND UNIVERSITY EDUCATION: A SYSTEMATIC REVIEW \- VisualCOM Scientific Publications, https://visualcompublications.es/revVISUAL/article/download/5206/3485 180\. What Happened to Vine? How a Once-Viral App Died \- EM360Tech, https://em360tech.com/tech-articles/what-happened-vine-how-once-viral-app-died 181\. Vine (service) \- Wikipedia, https://en.wikipedia.org/wiki/Vine\_(service) 182\. Vine: A Circuit of Culture \- Cultural History of the Internet, https://internet.medialities.org/student-projects/fall-2021/liwen/ 183\. I Heard it through the... Vine: A Look into Virality and its Importance, https://scholars.unh.edu/cgi/viewcontent.cgi?article=1272\&context=honors 184\. Visual cross-platform analysis: digital methods to research social ..., https://www.tandfonline.com/doi/full/10.1080/1369118X.2018.1486871 185\. Vine's Constraint on Value Versus Creativity \- LBBOnline, https://www.lbbonline.com/news/vines-constraint-on-value-versus-creativity 186\. Vine – A quick rise and fall \- Digital Media Knowledge, https://digitalmediaknowledge.com/audiences/vine-a-quick-rise-and-fall/ 187\. Vine's Influence After Death \- NSHS Denebola, https://nshsdenebola.com/vines-influence-after-death/ 188\. The best, weirdest Instagram meme accounts you're not following., https://slate.com/culture/2022/05/best-instagram-meme-accounts-shitposts.html 189\. 47 Instagram Reels Ideas for Engagement & Growth in 2025 | Planable, https://planable.io/blog/instagram-reels-ideas/ 190\. The Easy Guide to a Curated Instagram Feed \- Sculpt, https://wearesculpt.com/blog/curated-instagram-feed/ 191\. The Social Media Industry: Where Is it Heading?, https://digitalcommons.montclair.edu/cgi/viewcontent.cgi?article=1053\&context=management-facpubs 192\. Short-Form Video Platforms | YouTube Shorts vs TikTok vs Instagram Reels, https://opace.agency/blog/short-form-video-platforms 193\. The Rise of Short-Form Content: A Deep Dive into TikTok and Instagram Reels \- Quintly, https://www.quintly.com/blog/deep-dive-tiktok-and-instagram-reels 194\. TikTok vs Vine: A Comparison of Two Social Platforms, https://www.tiktok.com/@livetwocreate/video/6785779539566939398 195\. What are your thoughts on short-form video increasingly dominating social media? \- Reddit, https://www.reddit.com/r/Millennials/comments/184r3jq/what\_are\_your\_thoughts\_on\_shortform\_video/ 196\. 10 Things Digital Marketers should know about TikTok \- Builtvisible, https://builtvisible.com/10-things-digital-marketers-should-know-about-tiktok/ 197\. An In-Depth Look at Marketing on TikTok, https://digitalmarketinginstitute.com/blog/an-in-depth-look-at-marketing-on-tiktok 198\. TikTok and Cultural Diffusion: A Study of the Platform's Impact on Global Cultural Exchange, https://bcpublication.org/index.php/FHSS/article/download/7838/7794/9688 199\. Bridging Cultures or Homogenizing Society? Exploring \- POLITesi \- Politecnico di Milano, https://www.politesi.polimi.it/retrieve/cd816259-f6cd-42cc-bd86-9a6dbb6da1a7/2023\_05\_AliaKaouel.pdf 200\. TikTok's influence on Generation Z's Buying Habits and Behavior \- FIU Digital Commons, https://digitalcommons.fiu.edu/cgi/viewcontent.cgi?article=1009\&context=gsc 201\. SCROLLING INTO OBLIVION: THE COGNITIVE TOLL OF BRAIN ROT ON GEN Z, https://bbf.digital/scrolling-into-oblivion-the-cognitive-toll-of-brain-rot-on-gen-z 202\. The Psychological Conditioning of Brainrot \- Florida Atlantic University, https://www.fau.edu/thrive/students/thrive-thursdays/psychological\_conditioning\_brainrot/brainrot/ 203\. Brain Rot: The Age of Distractions \- Clark Chronicle, https://clarkchronicle.com/features/2024/12/12/brain-rot-the-age-of-distractions/ 204\. The effects of 'brain rot': How junk content is damaging our minds \- El Pais English \- EL PAÍS, https://english.elpais.com/technology/2024-12-26/the-effects-of-brain-rot-how-junk-content-is-damaging-our-minds.html 205\. “Sephora 10 Year Olds” and the Digital Attention Economy \- Tiger Times, https://erietigertimes.com/11983/opinion/sephora-10-year-olds-and-the-digital-attention-economy/ 206\. Terminally Online Girl \- TikTok, https://www.tiktok.com/discover/terminally-online-girl 207\. Marshall McLuhan \- Media Ecology \- Dawson College, https://www.dawsoncollege.qc.ca/ai/wp-content/uploads/sites/180/16-McLuhan-Media-Ecology.pdf 208\. The Medium and McLuhan's Message \- Fordham Research Commons, https://research.library.fordham.edu/cgi/viewcontent.cgi?article=1008\&context=comm\_facultypubs 209\. How Hyper-Local Meme Accounts Took Over the World \- VICE, https://www.vice.com/en/article/hyper-local-instagram-meme-accounts/ 210\. Memes to an end: Inside the world of Calgary's "dankest" Instagram meme pages, https://calgaryjournal.ca/2017/03/07/memes-to-an-end-inside-the-world-of-calgary-s-dankest-instagram-meme-pages/ 211\. Gaslight, Gatekeep, Girlboss: How Memes Became A Cry For Help \- Refinery29, https://www.refinery29.com/en-us/2021/05/10454992/instagram-cry-for-help-meme-trend 212\. What are some ways to curate my social media feeds to ensure I'm exposed to educational and inspiring content rather than mindless scrolling? \- Reddit, https://www.reddit.com/r/socialmedia/comments/14595ao/what\_are\_some\_ways\_to\_curate\_my\_social\_media/ 213\. What's the meme on Instagram "No problem\! Here's information about Mercedes CLR GTR:"? : r/NoStupidQuestions \- Reddit, https://www.reddit.com/r/NoStupidQuestions/comments/1co82mv/whats\_the\_meme\_on\_instagram\_no\_problem\_heres/ 214\. Multimodality on the Internet: Recent Meme Genres as Tools for Online Communication Annaëlle Zollinger \- Serval, https://serval.unil.ch/resource/serval:BIB\_S\_32353.P001/REF.pdf 215\. \[TOMT\]\[meme format\]\[2000s???,2010s and 2020s\] Whats the name of the memes from 'Intellectuals' instagram meme accounts that have text in the middle and picture filling the whole background \- Reddit, https://www.reddit.com/r/tipofmytongue/comments/s4kc73/tomtmeme\_format2000s2010s\_and\_2020s\_whats\_the/ 216\. Most Popular Memes on Social Media Right Now \- Socialinsider, https://www.socialinsider.io/blog/most-popular-memes-on-social-media-right-now/ 217\. 100+ Instagram captions meme \+ Free AI Caption Generator \- Flick, https://www.flick.social/captions/instagram-captions-meme 218\. Meme Templates — Free and Customizable \- Kapwing, https://www.kapwing.com/meme-templates 219\. Short-Form Video Statistics Every Marketer Should Know \- Kapwing, https://www.kapwing.com/resources/short-form-video/ 220\. Is Byte the new Vine or is it TikTok all the way? | Mediamodifier, https://mediamodifier.com/blog/byte-new-vine-tiktok 221\. Why 30 Million Users Abandoned Vine? \- Product Monk, https://www.productmonk.io/p/vine-failure 222\. Try Not To Feel Old Challenge \- Vine 10 Years Later \- YouTube, https://m.youtube.com/watch?v=73KqBKdovlQ\&pp=ygUJI29zY2FyZ2dj 223\. Legend Vines Then and Now \#vine \#vines \#thomassanders \#kingbach \#might... | king bach | TikTok, https://www.tiktok.com/@transitions\_community/video/7353667597591711019 224\. Remembering the Best Vines: Then And Now \- TikTok, https://www.tiktok.com/@transitions\_community/video/7047007011736784175 225\. Vines Then and now \#vine \#vines \#funny \#thenandnow \#fyp \#foryou \#fo... | TikTok, https://www.tiktok.com/@transitions\_community/video/7039963175881854255 226\. Lele Pons Was Vine's Most Followed Woman: How a Rumor About Its Shutdown Helped Her Maintain Relevance Long After (Exclusive) \- People.com, https://people.com/lele-pons-shares-how-she-continued-to-thrive-after-vine-shutdown-exclusive-8775993 227\. Understanding Affordances in Short-Form Videos: A Performative Perspective, https://www.researchgate.net/publication/361336046\_Understanding\_Affordances\_in\_Short-Form\_Videos\_A\_Performative\_Perspective 228\. TikTok and the Rise of Algorithmic Meme Cultures \- Spectrum: Concordia University Research Repository, https://spectrum.library.concordia.ca/993401/1/Kowalchuk\_MA\_S2024.pdf 229\. Source-Critical Affordances in Social Media Apps \- International Journal of Communication, https://ijoc.org/index.php/ijoc/article/download/21892/4769 230\. The Medium Is the Mania: Anxiety as a Feature, Not a Bug, of Digital Media, https://www.modernreformation.org/resources/essays/the-medium-is-the-mania-anxiety-as-a-feature-not-a-bug-of-digital-media 231\. The Biological Foundation of Media Ecology Robert K. Logan Professor Emeritus, Department of Physics, University of Toronto Sen, https://www.physics.utoronto.ca/documents/204/BioMedEcol.pdf 232\. The Rise of Viral Content: How Memes and Micro-Content Are Redefining Entertainment \- Pioneering Digital Performance Marketing Agency \- Monolith IMC, https://www.monolithimc.com/the-rise-of-viral-content-how-memes-and-micro-content-are-redefining-entertainment/ 233\. Post Memes or Post-Meme: TikTok and the Rise of Algorithmic ..., https://spectrum.library.concordia.ca/id/eprint/993401/ 234\. Audio, Evolution, and Memes: Why TikTok Is The First YouTube Challenger \- NpappaG, https://npappag.com/2020/10/29/audio-memes-why-tiktok-is-the-first-youtube-challenger/ 235\. Understanding TikTok Usage: Communication Strategy of ByteDance Based on the Background of New Media \- Atlantis Press, https://www.atlantis-press.com/article/125984496.pdf 236\. ByteDance's Global Localization Strategy: A Deep Dive into Cultural Adaptation and Market Resonance, https://vital.lib.tsu.ru/vital/access/services/Download/vital:21909/SOURCE01 237\. (PDF) Research on the Overseas Operation Strategy of Chinese Platform-A Study Case of TikTok \- ResearchGate, https://www.researchgate.net/publication/375551163\_Research\_on\_the\_Overseas\_Operation\_Strategy\_of\_Chinese\_Platform-A\_Study\_Case\_of\_TikTok 238\. An Analysis of TikTok's Digital Marketing Capabilities and Its Effectiveness for Brands and Businesses Across Different Industries, https://digitalcommons.lindenwood.edu/cgi/viewcontent.cgi?article=1532\&context=theses 239\. The Impact of TikTok on Students: A Literature Review \- Article (Preprint v1) by Atinafu Regasa et al. | Qeios, https://www.qeios.com/read/EPFGO6 240\. TikTok's 2025 predictions might change how you market \- ContentGrip, https://www.contentgrip.com/tiktok-whats-next-2025-trends-summary/ 241\. What is FYP (For You Page) & how to get featured? \- ContentStudio, https://contentstudio.io/social-media-terms/for-you-page 242\. How to go viral on TikTok in 2025 – Your complete guide to success \- MyDesigns, https://mydesigns.io/blog/how-to-go-viral-on-tiktok/ 243\. TikTok Guide: Everything You Should Know About TikTok \- Viral Nation, https://www.viralnation.com/resources/blog/tiktok-guide-everything-you-should-know-about-tiktok 244\. TikTok Algorithm Guide 2025: How to Get Your Videos on FYPs \- Buffer, https://buffer.com/resources/tiktok-algorithm/ 245\. Unravelling the Secrets of TikTok Algorithm: A 2024 Guide \- Ocoya, https://www.ocoya.com/blog/tiktok-algorithm-secrets 246\. What Is The 'For You Page' (FYP) & Why It Matters \- Foundation Marketing, https://foundationinc.co/lab/for-you-page/ 247\. Playing with TikTok: algorithmic culture and the future of creative work \- ResearchGate, https://www.researchgate.net/publication/345376401\_Playing\_with\_TikTok\_algorithmic\_culture\_and\_the\_future\_of\_creative\_work 248\. For who page? Tiktok creators' algorithmic dependencies \- DRS Digital Library, https://dl.designresearchsociety.org/cgi/viewcontent.cgi?article=1248\&context=iasdr 249\. Exploring Chagga Culture Through Duets and Stitches \- TikTok, https://www.tiktok.com/@de\_chagga/video/7488647013962239287 250\. Exploring Fun TikTok Filters and Challenges, https://www.tiktok.com/@9ineplayss/video/7490620209431203094 251\. Understanding Stitch: Voice and Duet Dynamics \- TikTok, https://www.tiktok.com/@michaelsoepic/video/7462629136440347947 252\. Exploring Cringe Culture: A Look Back at TikTok Duets, https://www.tiktok.com/@dunkaren/video/7486689674803744046 253\. Driving into the Digital Age: Exploring the platform vernacular of Formula One's participatory culture on TikTok \- Utrecht University Student Theses Repository Home, https://studenttheses.uu.nl/handle/20.500.12932/44022 254\. Understanding Young Adults' TikTok Usage \----- ​Real People, Creative Videos that Makes Your Day \- Communication, https://communication.ucsd.edu/\_files/undergrad/yang-yuxin-understanding-young-adults-tiktok-usage.pdf 255\. Extending the Internet meme: Conceptualizing technological mimesis and imitation publics on the TikTok platform \- ResearchGate, https://www.researchgate.net/publication/347991716\_Extending\_the\_Internet\_meme\_Conceptualizing\_technological\_mimesis\_and\_imitation\_publics\_on\_the\_TikTok\_platform 256\. The CCP's Digital Charm Offensive: How TikTok's Search Algorithm and Pro-China Influence Networks Indoctrinate GenZ Users in the, https://networkcontagion.us/wp-content/uploads/NCRI-Report\_-The-CCPs-Digital-Charm-Offensive.pdf 257\. The Creeping Influence of the Extreme Right's Meme Subculture in Southeast Asia's TikTok Community – GNET, https://gnet-research.org/2024/04/08/the-creeping-influence-of-the-extreme-rights-meme-subculture-in-southeast-asias-tiktok-community/ 258\. Cross-Cultural comparison of TikTok uses and gratifications \- ResearchGate, https://www.researchgate.net/publication/374829147\_Cross-Cultural\_comparison\_of\_TikTok\_uses\_and\_gratifications 259\. (PDF) GENERATION Z'S LINGOS ON TIKTOK: ANALYSIS OF EMERGING LINGUISTIC STRUCTURES \- ResearchGate, https://www.researchgate.net/publication/384965246\_GENERATION\_Z'S\_LINGOS\_ON\_TIKTOK\_ANALYSIS\_OF\_EMERGING\_LINGUISTIC\_STRUCTURES 260\. Year on TikTok 2024: Creativity and Community Impact, https://newsroom.tiktok.com/en-us/year-on-tiktok-2024 261\. Brain rot \- Wikipedia, https://en.wikipedia.org/wiki/Brain\_rot 262\. Brainrot: A Complete Guide \- wikiHow, https://www.wikihow.com/Brainrot 263\. Did the meaning of "brainrot" change over the past year? : r/etymology \- Reddit, https://www.reddit.com/r/etymology/comments/1dfyxvf/did\_the\_meaning\_of\_brainrot\_change\_over\_the\_past/ 264\. What is "brainrot"? : r/NoStupidQuestions \- Reddit, https://www.reddit.com/r/NoStupidQuestions/comments/18mk3is/what\_is\_brainrot/ 265\. What Is Brain Rot? A Guide for Parents \- Bark, https://www.bark.us/blog/what-is-brainrot/ 266\. Why teenagers are deliberately seeking brain rot on TikTok | Psyche Ideas, https://psyche.co/ideas/why-teenagers-are-deliberately-seeking-brain-rot-on-tiktok 267\. The Internet Brainrot Iceberg Explained \- YouTube, https://www.youtube.com/watch?v=jxt86pjF6jE 268\. Is there a comprehensive(ish) list of all the "brainrot" meme terms? : r/NoStupidQuestions, https://www.reddit.com/r/NoStupidQuestions/comments/1cgk2l7/is\_there\_a\_comprehensiveish\_list\_of\_all\_the/ 269\. Explaining Every Brainrot: Memes, Trends, and Internet Culture | TikTok, https://www.tiktok.com/@officialmtclips/video/7352544183254519073 270\. Exploring the Brainrot Aesthetic and Its Linguistic Roots \- TikTok, https://www.tiktok.com/@etymologynerd/video/7443915815986023722 271\. Understanding Brainrot in Internet Culture: Exploring Gen Z Slang \- TikTok, https://www.tiktok.com/@english.withharry/video/7421427632648031496 272\. Skibidi Rizz Toilet Brainrot \- TikTok, https://www.tiktok.com/discover/skibidi-rizz-toilet-brainrot 273\. List of brain rot words : r/GenAlpha \- Reddit, https://www.reddit.com/r/GenAlpha/comments/1evj2ho/list\_of\_brain\_rot\_words/ 274\. Skibidi Toilet Ohio Sigma Rizzler Brain Rot \- TikTok, https://www.tiktok.com/discover/skibidi-toilet-ohio-sigma-rizzler-brain-rot 275\. Skibidi Toilet Gyatt Ohio Rizz \- YouTube, https://www.youtube.com/watch?v=Q92wAYSddlM 276\. you'll be gyatt \- brain rot \#hamilton feat. king skibidi toilet part 2 | TikTok, https://www.tiktok.com/@rizz.records.yt/video/7391231593626471711 277\. \#fyp \#gyat \#rizz \#ohio \#skibiditoilet \#pluh | TikTok, https://www.tiktok.com/@\_yunglimabean\_/video/7293880142768639274 278\. Skibidi rizz gyatt explained by internet etymologist \- YouTube, https://www.youtube.com/watch?v=1AH9CFmyH-0 279\. Gyatt Joy \- Rizztide Cover | Skibidi Sigma | Singing & Instruments \- TikTok, https://www.tiktok.com/@elliotcox01/video/7371824811867114785 280\. Brainrot Sayings \- TikTok, https://www.tiktok.com/discover/brainrot-sayings 281\. Anime Brain Rot Words List \- TikTok, https://www.tiktok.com/discover/anime-brain-rot-words-list 282\. Exploring Brainrot: Ricci vs Jynxzi Highlights \- TikTok, https://www.tiktok.com/@jynxzi.clip.sdaily/video/7439189760633097518 283\. DansGame Meaning | Gaming Slang by Dictionary.com, https://www.dictionary.com/e/emoji/dansgame/ 284\. Resident Sleeper Emote Explained | Twitch Emote of the Day \- TikTok, https://www.tiktok.com/@uwumi/video/7215398816680316202 285\. Brain Rot: Are We Rotting Our Minds in the Digital Age? | Blog of the APA, https://blog.apaonline.org/2025/04/07/brain-rot-are-we-rotting-our-minds-in-the-digital-age/ 286\. sociological research on brain rot \- Reddit, https://www.reddit.com/r/sociology/comments/1i1wuo8/sociological\_research\_on\_brain\_rot/ 287\. Exploring rotten corners of the internet \- the Epic, https://lhsepic.com/53799/in-depth/53799/ 288\. Is Social Media Giving You Brainrot? \- Verywell Mind, https://www.verywellmind.com/brainrot-8677487 289\. The TikTok Effect: Have We Lost Our Ability to Pay Attention? \- Media Marketing, https://www.media-marketing.com/en/opinion/the-tiktok-effect-have-we-lost-our-ability-to-pay-attention/ 290\. TikTok Brain Rot: Is The Media Platform Rotting Our Brains? \- Her Campus, https://www.hercampus.com/school/u-mass-amherst/tiktok-brain-rot-is-the-media-platform-rotting-our-brains/ 291\. Demystifying the New Dilemma of Brain Rot in the Digital Era: A Review \- PMC, https://pmc.ncbi.nlm.nih.gov/articles/PMC11939997/ 292\. Brain Rot Explained: How Digital Overload Affects Your Mind \- Inspira Health Network, https://www.inspirahealthnetwork.org/news/healthy-living/brain-rot-explained-how-digital-overload-affects-your-mind 293\. Brain Rot: The Impact on Young Adult Mental Health \- Newport Institute, https://www.newportinstitute.com/resources/co-occurring-disorders/brain-rot/ 294\. Do you have brain rot? Here's how to know — Calm Blog, https://www.calm.com/blog/brainrot 295\. 4 Ways Information Overload Impacts Our Mental Health and How to Cope, https://mindfulhealthsolutions.com/4-ways-information-overload-impacts-our-mental-health-and-how-to-cope/ 296\. The Link Between Digital Overload, Brain Rot, And ADHD, https://www.thebrainworkshop.com/adhd/the-link-between-digital-overload-brain-rot-and-adhd/ 297\. Brain Rot: Why Brain Health Matters Now More Than Ever | Psychology Today, https://www.psychologytoday.com/us/blog/brain-care-for-all/202412/brain-rot-why-brain-health-matters-now-more-than-ever 298\. 'Brain rot' and digital overload: more myth than menace \- UNSW Sydney, https://www.unsw.edu.au/newsroom/news/2024/10/brain-rot-more-myth-menace 299\. How Brain Rot is silently ruining our lives: A Psychological Perspective, https://www.psychologs.com/how-brain-rot-is-silently-ruining-our-lives-a-psychological-perspective/ 300\. How would brain rot factor into the culture of 2020s? : r/decadeology \- Reddit, https://www.reddit.com/r/decadeology/comments/1i0o6zj/how\_would\_brain\_rot\_factor\_into\_the\_culture\_of/ 301\. Uncategorized – webcurios, https://webcurios.co.uk/category/uncategorized/ 302\. Culture Gabfest | Podcast directory \- Poor Stuart's Guide, https://www.poorstuart.com/podcast-series/Culture-Gabfest/1261/ 303\. Decibel \#214 \- August 2022 by Red Flag Media \- Issuu, https://issuu.com/redflagmedia/docs/db214\_municipalwaste\_digitalissuered 304\. All Stars 8 Rate Reveal, Day 1: Rate Dirty : r/popheads \- Reddit, https://www.reddit.com/r/popheads/comments/1ipjlym/all\_stars\_8\_rate\_reveal\_day\_1\_rate\_dirty/ 305\. Slate Culture Podcast Republic, https://www.podcastrepublic.net/podcast/279188498 306\. Brainrot Meme Emote | Meme Twitch Emotes | Twitch Emote Funny | Youtube Emote | Discord Emote | Animated Emote | Twitch Alert Active \- Etsy, https://www.etsy.com/listing/1727693259/brainrot-meme-emote-meme-twitch-emotes 307\. Social Media \- Game Quitters, https://gamequitters.com/blog/social-media/ 308\. Twitch Slang You Need To Know In 2024 \- inStreamly, https://instreamly.com/posts/twitch-slang-you-need-to-know-in-2022/ 309\. Kappa Meaning | Pop Culture by Dictionary.com, https://www.dictionary.com/e/pop-culture/kappa/ 310\. BrainRot Live Streams \- Twitch, https://www.twitch.tv/directory/all/tags/BrainRot 311\. Top 10 Brain Rot \- Cat Talk, https://mhscattalk.com/12046/editorials/top-10-brain-rot/ 312\. Brain Rot Live Streams \- TikTok, https://www.tiktok.com/discover/brain-rot-live-streams 313\. Brainrotmaxxing 101 \- The Texas Orator, https://thetexasorator.com/2024/09/20/brainrotmaxxing-101/ 314\. Every Brain Rot Explained In 8 Minutes \- YouTube, https://www.youtube.com/watch?v=EkHoJqJwDkY 315\. Actual brain rot : r/pyrocynical \- Reddit, https://www.reddit.com/r/pyrocynical/comments/1bbd07p/actual\_brain\_rot/ 316\. Streamers are causing MASSIVE brainrot \- YouTube, https://www.youtube.com/watch?v=DlCzC1PxaqM 317\. Every Brainrot Explained In 8 Minutes | Vtuber React \- YouTube, https://www.youtube.com/watch?v=IsQHICL3Qz4 318\. TwitchChat: A Dataset for Exploring Livestream Chat \- AAAI, https://aaai.org/ojs/index.php/AIIDE/article/download/7439/7286/ 319\. My Twitch Chat has the HIGHEST TIER of BRAINROT.. \#shorts \#ytshorts \#youtbeshorts \#dbd \#dbdshorts \- YouTube, https://www.youtube.com/watch?v=UlHHhQpIy-s 320\. Twitch Chat Gave Us Brainrot : r/VirtualYoutubers \- Reddit, https://www.reddit.com/r/VirtualYoutubers/comments/1fep57n/twitch\_chat\_gave\_us\_brainrot/ 321\. I trained an Ai on 380,000 Twitch Chat messages, but it was "too hateful" \- YouTube, https://www.youtube.com/watch?v=UzyTl7Uu8GQ 322\. Streamer brainrot is real. : r/LivestreamFail \- Reddit, https://www.reddit.com/r/LivestreamFail/comments/14v01e2/streamer\_brainrot\_is\_real/ 323\. EPIC the Brainrot \- (The Twitchaca Saga): Mow Them Down \- YouTube, https://m.youtube.com/watch?v=KamzfSWEQWk 324\. Brain rot and this moment in online culture \- YouTube, https://www.youtube.com/watch?v=B3fKlY0l2Vg 325\. The brainrot is terminal \- Twitch, https://m.twitch.tv/northernlion/clip/TenaciousNastyFrogOhMyDog-6dkCHmRUGw5IbGxk 326\. Why 'Brain Rot' Culture Is Changing Society Forever \- YouTube, https://m.youtube.com/watch?v=uf0d63GP6rs 327\. What the sigma is going on with brainrot? \- The Urban Legend, https://www.urbanlegendnews.org/features/2024/12/09/what-the-sigma-is-going-on-with-brainrot/ 328\. The Brainrot Is Terminal... New Start New Me (Gamma Souls-like mode) \- Twitch, https://www.twitch.tv/pr1vatelime/clip/SarcasticInexpensiveGarageOneHand-jF8A\_DNixOVDLumt 329\. Do you prefer Youtube or Twitch? : r/VirtualYoutubers \- Reddit, https://www.reddit.com/r/VirtualYoutubers/comments/15mipoy/do\_you\_prefer\_youtube\_or\_twitch/ 330\. Exploring the Concept of Brainrot in Modern Culture \- TikTok, https://www.tiktok.com/@espeldo/video/7476306869678624055 331\. Memetic Moments: The Speed of Twitter Memes \- Journal of Digital Social Research (JDSR), https://jdsr.se/ojs/index.php/jdsr/article/view/95 332\. View of Slow Down\! Digital Deceleration Towards A Socialist Social Media | tripleC, https://www.triple-c.at/index.php/tripleC/article/view/1127/1334 333\. Mixture of Mutually Exciting Processes for Viral Diffusion \- Proceedings of Machine Learning Research, http://proceedings.mlr.press/v28/yang13a.pdf 334\. Identification and Prediction of an Internet Meme Flow Lifecycle\*,\*\* \- CEUR-WS.org, https://ceur-ws.org/Vol-2914/paper10.pdf
